"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const postman_1 = require("../parser/postman");
const basic_postman_collection_v2_0_json_1 = __importDefault(require("./mock_files/basic-postman_collection-v2.0.json"));
const basic_postman_collection_v2_1_json_1 = __importDefault(require("./mock_files/basic-postman_collection-v2.1.json"));
const grouped_postman_collection_v2_0_json_1 = __importDefault(require("./mock_files/grouped-postman_collection-v2.0.json"));
const grouped_postman_collection_v2_1_json_1 = __importDefault(require("./mock_files/grouped-postman_collection-v2.1.json"));
const postman_collection_unsupported_json_1 = __importDefault(require("./mock_files/postman_collection-unsupported.json"));
describe('parseConfigFromPostman', () => {
    it('throws invalid JSON format', () => {
        try {
            (0, postman_1.parseConfigFromPostman)('../fetch.ts');
        }
        catch (error) {
            (0, chai_1.expect)(() => {
                throw error;
            }).to.throw('Your Postman file contains an invalid JSON format!');
        }
    });
    it('throws unsupported collection version', () => {
        try {
            const collectionStr = JSON.stringify(postman_collection_unsupported_json_1.default);
            (0, postman_1.parseConfigFromPostman)(collectionStr);
        }
        catch (error) {
            (0, chai_1.expect)(() => {
                throw error;
            }).to.throw('Your Postman collection version is not supported. Please use v2.0 or v2.1!');
        }
    });
    describe('basic Postman collection', () => {
        it('[v2.0] - should converted to Monika config', () => {
            const collectionStr = JSON.stringify(basic_postman_collection_v2_0_json_1.default);
            const config = (0, postman_1.parseConfigFromPostman)(collectionStr);
            (0, chai_1.expect)(config.probes.length).to.equals(5);
            for (const [index, item] of basic_postman_collection_v2_0_json_1.default.item.entries()) {
                (0, chai_1.expect)(item.name).to.equals(config.probes[index].name);
                for (const req of config.probes[index].requests || []) {
                    const mode = item.request.body?.mode;
                    const language = item.request.body?.options?.raw?.language;
                    (0, chai_1.expect)(req.url).to.equals(item.request.url);
                    (0, chai_1.expect)(req.method).to.equals(item.request.method);
                    if (mode === 'formdata' ||
                        mode === 'urlencoded' ||
                        (mode === 'raw' && language === 'json')) {
                        (0, chai_1.expect)(req.body).to.deep.equals({ message: 'Hello, world!' });
                    }
                    const headers = req.headers || {};
                    if (mode === 'formdata' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('multipart/form-data');
                    }
                    if (mode === 'urlencoded' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('application/x-www-form-urlencoded');
                    }
                    if (mode === 'raw') {
                        if (language === 'json' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('application/json');
                        }
                        if (language === 'text' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('text/plain');
                        }
                    }
                }
            }
        });
        it('[v2.1] - should converted to Monika config', () => {
            const collectionStr = JSON.stringify(basic_postman_collection_v2_1_json_1.default);
            const config = (0, postman_1.parseConfigFromPostman)(collectionStr);
            (0, chai_1.expect)(config.probes.length).to.equals(5);
            for (const [index, item] of basic_postman_collection_v2_1_json_1.default.item.entries()) {
                (0, chai_1.expect)(item.name).to.equals(config.probes[index].name);
                for (const req of config.probes[index].requests || []) {
                    const mode = item.request.body?.mode;
                    const language = item.request.body?.options?.raw?.language;
                    (0, chai_1.expect)(req.url).to.equals(item.request.url.raw);
                    (0, chai_1.expect)(req.method).to.equals(item.request.method);
                    if (mode === 'formdata' ||
                        mode === 'urlencoded' ||
                        (mode === 'raw' && language === 'json')) {
                        (0, chai_1.expect)(req.body).to.deep.equals({ message: 'Hello, world!' });
                    }
                    const headers = req.headers || {};
                    if (mode === 'formdata' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('multipart/form-data');
                    }
                    if (mode === 'urlencoded' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('application/x-www-form-urlencoded');
                    }
                    if (mode === 'raw') {
                        if (language === 'json' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('application/json');
                        }
                        if (language === 'text' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('text/plain');
                        }
                    }
                }
            }
        });
    });
    describe('grouped Postman collection', () => {
        it('[v2.0] - should converted to Monika config', () => {
            const collectionStr = JSON.stringify(grouped_postman_collection_v2_0_json_1.default);
            const config = (0, postman_1.parseConfigFromPostman)(collectionStr);
            (0, chai_1.expect)(config.probes.length).to.equals(2);
            for (const [index, item] of grouped_postman_collection_v2_0_json_1.default.item.entries()) {
                (0, chai_1.expect)(item.name).to.equals(config.probes[index].name);
                for (const [rIndex, req] of (config.probes[index].requests || []).entries()) {
                    const mode = item.item[rIndex].request.body?.mode;
                    const language = item.item[rIndex].request.body?.options?.raw?.language;
                    (0, chai_1.expect)(req.url).to.equals(item.item[rIndex].request.url);
                    (0, chai_1.expect)(req.method).to.equals(item.item[rIndex].request.method);
                    if (mode === 'formdata' ||
                        mode === 'urlencoded' ||
                        (mode === 'raw' && language === 'json')) {
                        (0, chai_1.expect)(req.body).to.deep.equals({ message: 'Hello, world!' });
                    }
                    const headers = req.headers || {};
                    if (mode === 'formdata' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('multipart/form-data');
                    }
                    if (mode === 'urlencoded' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('application/x-www-form-urlencoded');
                    }
                    if (mode === 'raw') {
                        if (language === 'json' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('application/json');
                        }
                        if (language === 'text' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('text/plain');
                        }
                    }
                }
            }
        });
        it('[v2.1] - should converted to Monika config', () => {
            const collectionStr = JSON.stringify(grouped_postman_collection_v2_1_json_1.default);
            const config = (0, postman_1.parseConfigFromPostman)(collectionStr);
            (0, chai_1.expect)(config.probes.length).to.equals(2);
            for (const [index, item] of grouped_postman_collection_v2_1_json_1.default.item.entries()) {
                (0, chai_1.expect)(item.name).to.equals(config.probes[index].name);
                for (const [rIndex, req] of (config.probes[index].requests || []).entries()) {
                    const mode = item.item[rIndex].request.body?.mode;
                    const language = item.item[rIndex].request.body?.options?.raw?.language;
                    (0, chai_1.expect)(req.url).to.equals(item.item[rIndex].request.url?.raw);
                    (0, chai_1.expect)(req.method).to.equals(item.item[rIndex].request.method);
                    if (mode === 'formdata' ||
                        mode === 'urlencoded' ||
                        (mode === 'raw' && language === 'json')) {
                        (0, chai_1.expect)(req.body).to.deep.equals({ message: 'Hello, world!' });
                    }
                    const headers = req.headers || {};
                    if (mode === 'formdata' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('multipart/form-data');
                    }
                    if (mode === 'urlencoded' && 'Content-Type' in headers) {
                        (0, chai_1.expect)(headers['Content-Type']).to.equals('application/x-www-form-urlencoded');
                    }
                    if (mode === 'raw') {
                        if (language === 'json' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('application/json');
                        }
                        if (language === 'text' && 'Content-Type' in headers) {
                            (0, chai_1.expect)(headers['Content-Type']).to.equals('text/plain');
                        }
                    }
                }
            }
        });
    });
});
//# sourceMappingURL=parse-postman.test.js.map