"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfig = void 0;
const node_child_process_1 = require("node:child_process");
const node_fs_1 = require("node:fs");
const promises_1 = require("node:fs/promises");
const node_os_1 = require("node:os");
const core_1 = require("@oclif/core");
const js_yaml_1 = __importDefault(require("js-yaml"));
const context_1 = require("../../context");
const pino_1 = require("../../utils/pino");
const get_1 = require("./get");
const parse_1 = require("./parser/parse");
async function createConfig() {
    const { flags } = (0, context_1.getContext)();
    const isConvertFromOtherFormat = flags.har || flags.insomnia || flags.postman || flags.sitemap || flags.text;
    if (!isConvertFromOtherFormat) {
        pino_1.log.info('Opening Monika Configuration Generator in your default browser...');
        open('https://hyperjumptech.github.io/monika-config-generator/');
        return;
    }
    const { path, type } = getPathAndType();
    if (!(0, node_fs_1.existsSync)(path)) {
        throw new Error(`Couldn't found the ${path} file.`);
    }
    const { force, output } = flags;
    if ((0, node_fs_1.existsSync)(output) && !force) {
        const answer = await core_1.ux.ux.prompt(`\n${output} file is already exists. Overwrite (Y/n)?`);
        if (answer.toLowerCase() !== 'y') {
            pino_1.log.warn('Command cancelled. You can use the -o flag to specify an output file or --force to overwrite without prompting.');
            return;
        }
    }
    const parse = await (0, parse_1.parseByType)(path, type);
    const data = js_yaml_1.default.dump((0, get_1.addDefaultNotifications)(parse));
    await (0, promises_1.writeFile)(output, data, {
        encoding: 'utf8',
    });
    pino_1.log.info(`${output} file has been created.`);
}
exports.createConfig = createConfig;
function open(url) {
    const operatingSystem = (0, node_os_1.type)();
    switch (operatingSystem) {
        case 'Darwin': {
            (0, node_child_process_1.spawnSync)('open', [url]);
            break;
        }
        case 'Linux': {
            (0, node_child_process_1.spawnSync)('xdg-open', [url]);
            break;
        }
        case 'Windows NT': {
            (0, node_child_process_1.spawnSync)('start', [url]);
            break;
        }
        default: {
            throw new Error(`Unknown operating system: ${operatingSystem}`);
        }
    }
}
function getPathAndType() {
    const { flags } = (0, context_1.getContext)();
    if (flags.har) {
        return { path: flags.har, type: 'har' };
    }
    if (flags.insomnia) {
        return { path: flags.insomnia, type: 'insomnia' };
    }
    if (flags.postman) {
        return { path: flags.postman, type: 'postman' };
    }
    if (flags.sitemap) {
        return { path: flags.sitemap, type: 'sitemap' };
    }
    if (flags.text) {
        return { path: flags.text, type: 'text' };
    }
    throw new Error('Unknown format');
}
//# sourceMappingURL=create.js.map