"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseByType = void 0;
const promises_1 = require("node:fs/promises");
const node_path_1 = __importDefault(require("node:path"));
const is_url_1 = __importDefault(require("is-url"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const http_1 = require("../../../utils/http");
const har_1 = require("./har");
const insomnia_1 = require("./insomnia");
const postman_1 = require("./postman");
const sitemap_1 = require("./sitemap");
const text_1 = require("./text");
async function parseByType(source, type) {
    const config = (0, is_url_1.default)(source)
        ? await getConfigFileFromUrl(source)
        : await (0, promises_1.readFile)(source, { encoding: 'utf8' });
    const isEmpty = config.length === 0;
    if (isEmpty) {
        throw new Error(`Failed to read ${source}, the file is empty.`);
    }
    const extension = node_path_1.default.extname(source);
    if (type === 'har')
        return (0, har_1.parseHarFile)(config);
    if (type === 'text')
        return (0, text_1.parseConfigFromText)(config);
    if (type === 'postman')
        return (0, postman_1.parseConfigFromPostman)(config);
    if (type === 'sitemap')
        return (0, sitemap_1.parseConfigFromSitemap)(config);
    if (type === 'insomnia')
        return (0, insomnia_1.parseInsomnia)(config, extension.replace('.', ''));
    return parseConfigByExt({
        config,
        extension,
        source,
    });
}
exports.parseByType = parseByType;
async function getConfigFileFromUrl(url) {
    const config = await fetchConfigFile(url);
    const isEmpty = config.length === 0;
    if (isEmpty) {
        throw new Error(`The remote file ${url} is empty. Please check the URL or your connection again.`);
    }
    return config;
}
async function fetchConfigFile(url) {
    try {
        const { data } = await (0, http_1.sendHttpRequest)({ url });
        return data;
    }
    catch {
        throw new Error(`The configuration file in ${url} is unreachable.`);
    }
}
function parseConfigByExt({ config, extension, source, }) {
    const isYaml = ['.yaml', '.yml'].includes(extension);
    if (isYaml) {
        return js_yaml_1.default.load(config, { json: true });
    }
    return (0, is_url_1.default)(source) ? config : JSON.parse(config);
}
//# sourceMappingURL=parse.js.map