"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseConfigFromSitemap = void 0;
const fast_xml_parser_1 = require("fast-xml-parser");
const joi_1 = __importDefault(require("joi"));
const context_1 = require("../../../context");
const flag_1 = require("../../../flag");
const sitemapValidator = joi_1.default.object({
    config: joi_1.default.object({
        urlset: joi_1.default.object({
            url: joi_1.default.array().items(joi_1.default.object({
                loc: joi_1.default.string(),
                'xhtml:link': joi_1.default.array().items(joi_1.default.object({ '@_href': joi_1.default.string() })),
            })),
        }),
    }),
});
const generateProbesFromXml = (parseResult) => {
    const { value } = sitemapValidator.validate(parseResult, {
        allowUnknown: true,
    });
    const probes = value?.urlset?.url?.map((item) => {
        const requests = [
            {
                url: item?.loc,
                method: 'GET',
                timeout: 10000,
            },
        ];
        if (item['xhtml:link']) {
            for (const alt of item['xhtml:link']) {
                requests.push({
                    url: alt['@_href'],
                    method: 'GET',
                    timeout: 10000,
                });
            }
        }
        return {
            id: item?.loc,
            name: item?.loc,
            requests,
            alerts: [],
        };
    });
    return probes ?? [];
};
const generateProbesFromXmlOneProbe = (parseResult) => {
    let probe;
    let requests = [];
    const config = sitemapValidator.validate(parseResult, {
        allowUnknown: true,
    }).value;
    const resources = config?.urlset?.url;
    for (const [, item] of resources.entries()) {
        requests = [
            ...requests,
            {
                url: item.loc,
                method: 'GET',
                timeout: 10000,
                body: '',
                followRedirects: (0, context_1.getContext)().flags['follow-redirects'],
            },
        ];
        if (item['xhtml:link']) {
            for (const alt of item['xhtml:link']) {
                requests = [
                    ...requests,
                    {
                        url: alt['@_href'],
                        method: 'GET',
                        timeout: 10000,
                        body: '',
                        followRedirects: (0, context_1.getContext)().flags['follow-redirects'],
                    },
                ];
            }
        }
        const url = new URL(item.loc);
        probe = {
            id: url.host,
            name: url.host,
            requests,
            interval: flag_1.monikaFlagsDefaultValue['config-interval'],
            alerts: [
                {
                    assertion: 'response.status < 200 or response.status > 299',
                    message: 'HTTP Status is not 200',
                },
                {
                    assertion: 'response.time > 2000',
                    message: 'Response time is more than 2000ms',
                },
            ],
        };
    }
    return probe ? [probe] : [];
};
const parseConfigFromSitemap = (configString) => {
    try {
        const parser = new fast_xml_parser_1.XMLParser({ ignoreAttributes: false });
        const xmlObj = parser.parse(configString);
        let probes = generateProbesFromXml(xmlObj);
        if ((0, context_1.getContext)().flags['one-probe']) {
            probes = generateProbesFromXmlOneProbe(xmlObj);
        }
        return { probes };
    }
    catch {
        throw new Error('Your Sitemap file contains an invalid Sitemap XML format !');
    }
};
exports.parseConfigFromSitemap = parseConfigFromSitemap;
//# sourceMappingURL=sitemap.js.map