"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const probe_1 = require("./probe");
const probe = {
    alerts: [],
    id: 'xVUcW',
    interval: 10,
    name: 'Sample Probe',
};
describe('Probe cache', () => {
    beforeEach(() => {
        for (const { id } of (0, probe_1.getProbes)()) {
            (0, probe_1.deleteProbe)(id);
        }
    });
    it('should add a probe', () => {
        // act
        (0, probe_1.addProbe)(probe);
        // assert
        (0, test_1.expect)((0, probe_1.findProbe)(probe.id)).eq(probe);
    });
    it('should update a probe', () => {
        // arrange
        (0, probe_1.addProbe)(probe);
        const updatedName = 'Updated Probe';
        // act
        const isUpdated = (0, probe_1.updateProbe)(probe.id, { ...probe, name: updatedName });
        // assert
        (0, test_1.expect)(isUpdated).eq(true);
        (0, test_1.expect)((0, probe_1.findProbe)(probe.id)?.name).eq(updatedName);
    });
    it('should not update a nonexistent probe', () => {
        // arrange
        const updatedName = 'Updated Probe';
        // act
        const isUpdated = (0, probe_1.updateProbe)('9WpFB', { ...probe, name: updatedName });
        // assert
        (0, test_1.expect)(isUpdated).eq(false);
        (0, test_1.expect)((0, probe_1.findProbe)('9WpFB')).undefined;
    });
    it('should get all probes', () => {
        // arrange
        (0, probe_1.addProbe)(probe);
        // act
        const probes = (0, probe_1.getProbes)();
        // assert
        (0, test_1.expect)(probes.length).eq(1);
    });
    it('should not remove a nonexistent probe', () => {
        // arrange
        (0, probe_1.addProbe)(probe);
        // act
        const isDeleted = (0, probe_1.deleteProbe)('9WpFB');
        // assert
        (0, test_1.expect)(isDeleted).eq(false);
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(1);
    });
    it('should remove a probe', () => {
        // arrange
        (0, probe_1.addProbe)(probe);
        // act
        const isDeleted = (0, probe_1.deleteProbe)(probe.id);
        // assert
        (0, test_1.expect)(isDeleted).eq(true);
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(0);
    });
    it('should set probes', () => {
        // arrange
        (0, probe_1.addProbe)(probe);
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(1);
        // act
        (0, probe_1.setProbes)([probe]);
        // assert
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(1);
    });
});
//# sourceMappingURL=probe.test.js.map