"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeConfig = void 0;
const node_crypto_1 = require("node:crypto");
const looper_1 = require("../../looper");
const _1 = require(".");
const context_1 = require("../../context");
const DEFAULT_TLS_EXPIRY_REMINDER_DAYS = 30;
const DEFAULT_STATUS_NOTIFICATION = '0 6 * * *';
function sanitizeConfig(config) {
    const isSymonMode = (0, _1.isSymonModeFrom)((0, context_1.getContext)().flags);
    const { certificate, notifications = [], version, probes } = config;
    const sanitizedConfigWithoutVersion = {
        ...config,
        probes: probes.map((probe) => (0, looper_1.sanitizeProbe)(isSymonMode, probe)),
        certificate: sanitizeCertificate(certificate),
        notifications,
        'status-notification': config['status-notification'] || DEFAULT_STATUS_NOTIFICATION,
    };
    return {
        ...sanitizedConfigWithoutVersion,
        version: version || md5Hash(sanitizedConfigWithoutVersion),
    };
}
exports.sanitizeConfig = sanitizeConfig;
function md5Hash(data) {
    return (0, node_crypto_1.createHash)('md5').update(JSON.stringify(data)).digest('hex');
}
function sanitizeCertificate(certificate) {
    if (!certificate) {
        return certificate;
    }
    return {
        ...certificate,
        reminder: certificate.reminder || DEFAULT_TLS_EXPIRY_REMINDER_DAYS,
    };
}
//# sourceMappingURL=sanitize.js.map