"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const chai_1 = require("chai");
const sort_1 = require("./sort");
// arrange
const probes = [
    {
        id: '9t65v',
        name: 'Example',
        interval: 3000,
        requests: [],
        alerts: [],
    },
    {
        id: '5zm60',
        name: 'Example 2',
        interval: 3000,
        requests: [],
        alerts: [],
    },
];
describe('Sort probes', () => {
    describe('Without id flag', () => {
        it('should not change probe order', () => {
            // act
            const sortedProbes = (0, sort_1.sortProbes)(probes);
            // assert
            (0, test_1.expect)(sortedProbes).deep.eq(probes);
        });
    });
    describe('With id flag', () => {
        it('should throw due to invalid id', () => {
            // assert
            chai_1.assert.throws(() => (0, sort_1.sortProbes)(probes, 'm91us'));
        });
        it('should order probes by id flag', () => {
            // act
            const sortedProbes = (0, sort_1.sortProbes)(probes, '5zm60,9t65v');
            // assert
            (0, test_1.expect)(sortedProbes[0]).deep.eq(probes[1]);
            (0, test_1.expect)(sortedProbes[1]).deep.eq(probes[0]);
        });
        it('should order probes by id flag (duplicate id)', () => {
            // act
            const sortedProbes = (0, sort_1.sortProbes)(probes, '5zm60,9t65v,5zm60');
            // assert
            (0, test_1.expect)(sortedProbes[0]).deep.eq(probes[1]);
            (0, test_1.expect)(sortedProbes[1]).deep.eq(probes[0]);
            (0, test_1.expect)(sortedProbes[2]).deep.eq(probes[1]);
        });
        it('should order probes by spaced id flag', () => {
            // act
            const sortedProbes = (0, sort_1.sortProbes)(probes, '5zm60, 9t65v');
            // assert
            (0, test_1.expect)(sortedProbes[0]).deep.eq(probes[1]);
            (0, test_1.expect)(sortedProbes[1]).deep.eq(probes[0]);
        });
    });
});
//# sourceMappingURL=sort.test.js.map