"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateConfig = void 0;
const monika_notification_1 = require("@hyperjumptech/monika-notification");
const ajv_1 = __importDefault(require("ajv"));
const joi_1 = __importDefault(require("joi"));
const context_1 = require("../../context");
const monika_config_schema_json_1 = __importDefault(require("../../monika-config-schema.json"));
const validation_1 = require("./validation");
const _1 = require(".");
const validateConfig = async (configuration) => {
    const { notifications = [], probes = [], symon } = configuration;
    const [validatedProbes] = await Promise.all([
        (0, validation_1.validateProbes)(probes),
        (0, monika_notification_1.validateNotification)(notifications),
        validateSymon(symon),
    ]);
    const validatedConfig = {
        ...configuration,
        notifications,
        probes: validatedProbes,
    };
    if (!(0, _1.isSymonModeFrom)((0, context_1.getContext)().flags)) {
        validateConfigWithJSONSchema(validatedConfig);
    }
    return validatedConfig;
};
exports.validateConfig = validateConfig;
async function validateSymon(symonConfig) {
    if (!symonConfig) {
        return;
    }
    const schema = joi_1.default.object({
        id: joi_1.default.string().required(),
        url: joi_1.default.string().uri().required(),
        key: joi_1.default.string().required(),
        projectID: joi_1.default.string().required(),
        organizationID: joi_1.default.string().required(),
        interval: joi_1.default.number(),
    });
    await schema.validateAsync(symonConfig);
}
function validateConfigWithJSONSchema(config) {
    const ajv = new ajv_1.default();
    const validate = ajv.compile(monika_config_schema_json_1.default);
    const isValid = validate(config);
    if (!isValid) {
        throw new Error(`${validate.errors?.[0].instancePath} ${validate.errors?.[0].message}`);
    }
}
//# sourceMappingURL=validate.js.map