"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.watchConfigChanges = void 0;
const chokidar_1 = require("chokidar");
const is_url_1 = __importDefault(require("is-url"));
const context_1 = require("../../context");
const catch_error_handler_1 = require("../../utils/catch-error-handler");
const pino_1 = require("../../utils/pino");
const get_1 = require("./get");
const parse_1 = require("./parser/parse");
const _1 = require(".");
function watchConfigChanges() {
    const clearWatchers = [];
    for (const source of (0, context_1.getContext)().flags.config) {
        if ((0, is_url_1.default)(source)) {
            clearWatchers.push(pollingRemoteConfig(source));
            continue;
        }
        clearWatchers.push(watchConfigFile(source));
    }
    return clearWatchers;
}
exports.watchConfigChanges = watchConfigChanges;
function pollingRemoteConfig(url) {
    const intervalId = setInterval(async () => {
        try {
            const config = await (0, parse_1.parseByType)(url, 'monika');
            await (0, _1.updateConfig)(config);
        }
        catch (error) {
            pino_1.log.error((0, catch_error_handler_1.getErrorMessage)(error));
        }
    }, (0, context_1.getContext)().flags['config-interval'] * 1000);
    return {
        cancel: () => clearInterval(intervalId),
    };
}
function watchConfigFile(path) {
    const watcher = (0, chokidar_1.watch)(path).on('change', async () => {
        try {
            const config = await (0, get_1.getRawConfig)();
            await (0, _1.updateConfig)(config);
        }
        catch (error) {
            pino_1.log.error((0, catch_error_handler_1.getErrorMessage)(error));
        }
    });
    return {
        cancel: () => watcher.close(),
    };
}
//# sourceMappingURL=watcher.js.map