"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.printAllLogs = void 0;
const chalk_1 = __importDefault(require("chalk"));
const pino_1 = require("../../utils/pino");
const history_1 = require("./history");
// printAllLogs dumps the content of monika-logs.db onto the screen
async function printAllLogs() {
    await (0, history_1.openLogfile)();
    const data = await (0, history_1.getAllLogs)();
    for (const { id, probeId, requestUrl, responseStatus, responseTime, } of data) {
        pino_1.log.info(`${id} id: ${probeId} responseCode: ${chalk_1.default.keyword(getStatusColor(responseStatus))(String(responseStatus))} - ${requestUrl}, ${responseTime || '- '}ms`);
    }
}
exports.printAllLogs = printAllLogs;
/**
 * getStatusColor colorizes different statusCode
 * @param {any} responseCode is the httpStatus to colorize
 * @returns {string} color code based on chalk: Chalk & { supportsColor: ColorSupport };
 */
function getStatusColor(responseCode) {
    switch (Math.trunc(responseCode / 100)) {
        case 2: {
            return 'cyan';
        }
        case 4: {
            return 'orange';
        }
        case 5: // all 5xx errrors
        case 0: {
            // 0 is uri not found
            return 'red';
        }
    }
    return 'white';
}
//# sourceMappingURL=index.js.map