"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.logResponseTime = exports.checkIs24HourHasPassed = exports.resetlogs = exports.getLogLifeTimeInHour = exports.averageResponseTime = exports.minResponseTime = exports.maxResponseTime = void 0;
const date_fns_1 = require("date-fns");
// global variable
// we can say it is safe to use global variable here since the probe is processed sequentially as mentioned in probe/index.ts line 143: intentionally wait for a request to finish before processing next request in loop
let startTime24HourCycle = new Date();
let responseCount = 0;
let totalResponseTime = 0;
exports.maxResponseTime = 0;
exports.minResponseTime = 0;
exports.averageResponseTime = 0;
function getLogLifeTimeInHour() {
    const now = new Date();
    const diff = (0, date_fns_1.differenceInHours)(now, startTime24HourCycle);
    return diff || 1;
}
exports.getLogLifeTimeInHour = getLogLifeTimeInHour;
function resetlogs() {
    startTime24HourCycle = new Date();
    responseCount = 0;
    totalResponseTime = 0;
    exports.maxResponseTime = 0;
    exports.minResponseTime = 0;
    exports.averageResponseTime = 0;
}
exports.resetlogs = resetlogs;
function checkIs24HourHasPassed() {
    const now = new Date();
    const diffInHours = (0, date_fns_1.differenceInHours)(now, startTime24HourCycle);
    if (diffInHours > 24) {
        return true;
    }
    return false;
}
exports.checkIs24HourHasPassed = checkIs24HourHasPassed;
function logResponseTime(responseTime) {
    responseCount += 1;
    if (responseCount === 1) {
        // first time
        exports.maxResponseTime = responseTime;
        exports.minResponseTime = responseTime;
    }
    else if (responseTime > exports.maxResponseTime) {
        exports.maxResponseTime = responseTime;
    }
    else if (responseTime < exports.minResponseTime) {
        exports.minResponseTime = responseTime;
    }
    totalResponseTime += responseTime;
    exports.averageResponseTime = Math.floor(totalResponseTime / responseCount);
}
exports.logResponseTime = logResponseTime;
//# sourceMappingURL=response-time-log.js.map