"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = __importStar(require("chai"));
const chai_spies_1 = __importDefault(require("chai-spies"));
const sanitize_1 = require("../config/sanitize");
const flag_1 = require("../../flag");
const pino_1 = require("../../utils/pino");
const startup_message_1 = require("./startup-message");
chai_1.default.use(chai_spies_1.default);
const defaultConfig = {
    probes: [
        {
            id: 'uYJaw',
            name: 'Acme Inc.',
            interval: 3000,
            requests: [
                {
                    url: 'https://example.com',
                    headers: {},
                    body: '',
                    followRedirects: 21,
                    timeout: 0,
                },
            ],
            alerts: [
                {
                    assertion: 'response.status < 200 or response.status > 299',
                    id: '0BGKU',
                    message: 'HTTP Status is {{ response.status }}, expecting 2xx',
                },
            ],
        },
    ],
    notifications: [{ id: 'UVIsL', type: 'desktop' }],
    'status-notification': '',
    version: '1',
};
describe('Startup message', () => {
    // arrange
    let logMessage = '';
    let consoleLogMessage = '';
    beforeEach(() => {
        chai_1.default.spy.on(pino_1.log, 'info', (message) => {
            logMessage = message;
        });
        chai_1.default.spy.on(console, 'log', (message) => {
            consoleLogMessage = message;
        });
    });
    afterEach(() => {
        chai_1.default.spy.restore();
        logMessage = '';
        consoleLogMessage = '';
    });
    describe('Symon mode', () => {
        it('should show running in Symon mode', () => {
            // act
            (0, startup_message_1.logStartupMessage)({
                config: (0, sanitize_1.sanitizeConfig)({ probes: [] }),
                flags: (0, flag_1.sanitizeFlags)({
                    config: [],
                    symonKey: 'secret-key',
                    symonUrl: 'https://example.com',
                    verbose: false,
                }),
                isFirstRun: false,
            });
            // assert
            (0, chai_1.expect)(logMessage).eq('Running in Symon mode');
        });
    });
    describe('Monika mode', () => {
        describe('Notification message', () => {
            it('should show has no notification warning', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        notifications: [],
                        probes: [],
                        'status-notification': '',
                        version: '1',
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: false,
                    }),
                    isFirstRun: false,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('Notifications has not been set');
            });
        });
        describe('Starting or Restarting', () => {
            it('should show starting', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: defaultConfig,
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: false,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('Starting');
            });
            it('should show restarting', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: defaultConfig,
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: false,
                    }),
                    isFirstRun: false,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('Restarting');
            });
            it('should show probe and notification total', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: defaultConfig,
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: false,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('Probes: 1');
                (0, chai_1.expect)(consoleLogMessage).include('Notifications: 1');
            });
            it('should show empty notification total', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        notifications: [],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: false,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('Notifications: 0');
            });
        });
    });
    describe('Verbose', () => {
        describe('Probe detail', () => {
            it('should show probe detail', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        probes: [
                            {
                                ...defaultConfig.probes[0],
                                description: "Acme's company profile",
                            },
                        ],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('uYJaw');
                (0, chai_1.expect)(consoleLogMessage).include('Acme');
                (0, chai_1.expect)(consoleLogMessage).include("Acme's company profile");
                (0, chai_1.expect)(consoleLogMessage).include('-');
                (0, chai_1.expect)(consoleLogMessage).include('3000');
            });
            it('should show probe detail without description', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        notifications: [],
                        probes: [
                            {
                                id: 'uYJaw',
                                name: 'Acme Inc.',
                                interval: 3000,
                                requests: [],
                                alerts: [],
                            },
                        ],
                        'status-notification': '',
                        version: '1',
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('uYJaw');
                (0, chai_1.expect)(consoleLogMessage).include('Acme Inc.');
                (0, chai_1.expect)(consoleLogMessage).include('-');
                (0, chai_1.expect)(consoleLogMessage).include('3000');
            });
        });
        describe('Probe request detail', () => {
            it('should show probe request detail with default method', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: defaultConfig,
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('GET');
                (0, chai_1.expect)(consoleLogMessage).include('https://example.com');
            });
            it('should show probe detail', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        probes: [
                            ...defaultConfig.probes,
                            {
                                id: 'N3Omh',
                                name: 'Example',
                                interval: 3000,
                                requests: [
                                    {
                                        method: 'POST',
                                        url: 'https://example.com',
                                        headers: {},
                                        body: '',
                                        followRedirects: 21,
                                        timeout: 0,
                                    },
                                ],
                                alerts: [],
                            },
                        ],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('POST');
                (0, chai_1.expect)(consoleLogMessage).include('https://example.com');
            });
        });
        describe('Alert detail', () => {
            it('should show default alert', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: defaultConfig,
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('response.status < 200 or response.status > 299');
            });
            it('should show alert detail', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        probes: [
                            {
                                ...defaultConfig.probes[0],
                                alerts: [
                                    {
                                        id: 'fKBzx',
                                        assertion: 'response.status = 500',
                                        message: 'HTTP status is 500',
                                    },
                                ],
                            },
                        ],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('"assertion":"response.status = 500","message":"HTTP status is 500"}]');
            });
        });
        describe('Notification detail', () => {
            it('should show notification id and type', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        notifications: [{ id: 'UVIsL', type: 'desktop' }],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('Notifications');
                (0, chai_1.expect)(consoleLogMessage).include('UVIsL');
                (0, chai_1.expect)(consoleLogMessage).include('desktop');
            });
            it('should show notification detail for SMTP', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        notifications: [
                            {
                                id: '97AnH',
                                type: 'smtp',
                                data: {
                                    hostname: 'example.com',
                                    port: 25,
                                    username: 'name@example.com',
                                    password: '',
                                    recipients: ['john@example.com', 'jane@example.com'],
                                },
                            },
                        ],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('john@example.com, jane@example.com');
                (0, chai_1.expect)(consoleLogMessage).include('example.com');
                (0, chai_1.expect)(consoleLogMessage).include('25');
                (0, chai_1.expect)(consoleLogMessage).include('name@example.com');
            });
            it('should show notification detail with domain', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        notifications: [
                            {
                                id: 'N3Omh',
                                type: 'mailgun',
                                data: {
                                    recipients: ['john@example.com'],
                                    domain: 'https://example.com',
                                    apiKey: '',
                                },
                            },
                        ],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('https://example.com');
            });
            it('should show notification detail with url', () => {
                // arrange
                (0, startup_message_1.logStartupMessage)({
                    config: {
                        ...defaultConfig,
                        notifications: [
                            {
                                id: 'SxUhV',
                                type: 'webhook',
                                data: {
                                    url: 'https://example.com',
                                },
                            },
                        ],
                    },
                    flags: (0, flag_1.sanitizeFlags)({
                        config: [],
                        symonKey: '',
                        symonUrl: '',
                        verbose: true,
                    }),
                    isFirstRun: true,
                });
                // assert
                (0, chai_1.expect)(consoleLogMessage).include('https://example.com');
            });
        });
    });
    describe('Config file', () => {
        it('should show remote config message', () => {
            // act
            (0, startup_message_1.logStartupMessage)({
                config: defaultConfig,
                flags: (0, flag_1.sanitizeFlags)({
                    config: ['https://example.com/monika.yaml'],
                    symonKey: '',
                    symonUrl: '',
                    verbose: false,
                }),
                isFirstRun: false,
            });
            // assert
            (0, chai_1.expect)(logMessage).include('remote config');
        });
        it('should show file config message', () => {
            // act
            (0, startup_message_1.logStartupMessage)({
                config: defaultConfig,
                flags: (0, flag_1.sanitizeFlags)({
                    config: ['./monika.yaml'],
                    symonKey: '',
                    symonUrl: '',
                    verbose: false,
                }),
                isFirstRun: false,
            });
            // assert
            (0, chai_1.expect)(logMessage).include('config file');
        });
    });
    describe('Skip startup test', () => {
        it('should show startup message', () => {
            // act
            (0, startup_message_1.logStartupMessage)({
                config: defaultConfig,
                flags: (0, flag_1.sanitizeFlags)({
                    config: ['./test/testConfigs/simple-1p-1n.yaml'],
                    symonKey: '',
                    symonUrl: '',
                    verbose: false,
                }),
                isFirstRun: false,
            });
            // assert
            (0, chai_1.expect)(logMessage).include('Using config file:');
        });
        it('should not startup message', () => {
            // act
            (0, startup_message_1.logStartupMessage)({
                config: defaultConfig,
                flags: (0, flag_1.sanitizeFlags)({
                    'skip-start-message': true,
                    config: ['./test/testConfigs/simple-1p-1n.yaml'],
                    symonKey: '',
                    symonUrl: '',
                    verbose: false,
                }),
                isFirstRun: false,
            });
            // assert
            (0, chai_1.expect)(logMessage).not.include('Using config file:');
        });
    });
});
//# sourceMappingURL=startup-message.test.js.map