"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOSName = exports.getMessageForTerminate = exports.getMessageForStart = exports.getMessageForAlert = exports.getMonikaInstance = void 0;
const os_1 = require("os");
const util_1 = require("util");
const date_fns_1 = require("date-fns");
const Handlebars = __importStar(require("handlebars"));
const getos_1 = __importDefault(require("getos"));
const os_name_1 = __importDefault(require("os-name"));
const context_1 = require("../../context");
const public_ip_1 = require("../../utils/public-ip");
const incident_1 = require("../incident");
const getLinuxDistro = (0, util_1.promisify)(getos_1.default);
const getMonikaInstance = async (ipAddress) => {
    const osHostname = (0, os_1.hostname)();
    const publicNetworkInfo = (0, public_ip_1.getPublicNetworkInfo)();
    if (publicNetworkInfo) {
        const { city, isp } = publicNetworkInfo;
        return `${city} - ${isp} (${public_ip_1.publicIpAddress}) - ${osHostname} (${ipAddress})`;
    }
    return `${osHostname} (${[public_ip_1.publicIpAddress, ipAddress]
        .filter(Boolean)
        .join('/')})`;
};
exports.getMonikaInstance = getMonikaInstance;
const getExpectedMessage = (alert, response, isRecovery) => {
    const { status, data, headers, responseTime } = response;
    if (alert.message === '') {
        if (isRecovery) {
            return `The request is back to normal and passed the assertion: ${alert.assertion}`;
        }
        return `The request failed because the response did not pass the query: ${alert.assertion}. The actual response status is ${status} and the response time is ${responseTime}.`;
    }
    return Handlebars.compile(alert.message)({
        response: {
            size: typeof headers === 'string'
                ? undefined
                : Number(headers['content-length']),
            status,
            time: responseTime,
            body: data,
            headers,
        },
    });
};
async function getMessageForAlert({ probeID, alert, url, ipAddress, isRecovery, response, }) {
    const { userAgent } = (0, context_1.getContext)();
    const [monikaInstance, osName] = await Promise.all([
        (0, exports.getMonikaInstance)(ipAddress),
        getOSName(),
    ]);
    const recoveryOrIncident = isRecovery ? 'Recovery' : 'Incident';
    const meta = {
        type: isRecovery ? 'recovery' : 'incident',
        probeID,
        alertQuery: alert.assertion,
        url,
        time: (0, date_fns_1.format)(new Date(), 'yyyy-MM-dd HH:mm:ss XXX'),
        hostname: (0, os_1.hostname)(),
        privateIpAddress: ipAddress,
        publicIpAddress: public_ip_1.publicIpAddress,
        monikaInstance,
        version: userAgent,
    };
    const recoveryMessage = getRecoveryMessage(isRecovery, probeID, url);
    const expectedMessage = getExpectedMessage(alert, response, isRecovery);
    const bodyString = `Message: ${recoveryMessage}${expectedMessage}

${meta.url ? `URL: ${meta.url}` : `Probe ID: ${probeID}`}

Time: ${meta.time}

From: ${monikaInstance}

OS: ${osName}

Version: ${userAgent}`;
    const summary = `${expectedMessage}`;
    const message = {
        subject: `New ${recoveryOrIncident} from Monika`,
        body: bodyString,
        summary,
        meta,
    };
    return message;
}
exports.getMessageForAlert = getMessageForAlert;
function getRecoveryMessage(isRecovery, probeID, url) {
    const incidentDateTime = (0, incident_1.getIncidents)().find((incident) => incident.probeID === probeID && incident.probeRequestURL === url);
    if (!isRecovery || !incidentDateTime) {
        return '';
    }
    const incidentDuration = (0, date_fns_1.formatDistanceToNow)(incidentDateTime.createdAt, {
        includeSeconds: true,
    });
    const humanReadableIncidentDateTime = (0, date_fns_1.format)(incidentDateTime.createdAt, 'yyyy-MM-dd HH:mm:ss XXX');
    return `Target is back to normal after ${incidentDuration}. The incident happened at ${humanReadableIncidentDateTime}. `;
}
const getMessageForStart = async (hostname, ip) => {
    const { userAgent } = (0, context_1.getContext)();
    const [monikaInstance, osName] = await Promise.all([
        (0, exports.getMonikaInstance)(ip),
        getOSName(),
    ]);
    const monikaDetail = `${monikaInstance} - ${userAgent} - ${osName}`;
    return {
        subject: 'Monika is started',
        body: `Monika is running from ${monikaDetail}`,
        summary: `Monika is running from ${monikaDetail}`,
        meta: {
            type: 'start',
            time: new Date().toUTCString(),
            hostname,
            privateIpAddress: ip,
            publicIpAddress: public_ip_1.publicIpAddress,
            version: userAgent,
        },
    };
};
exports.getMessageForStart = getMessageForStart;
const getMessageForTerminate = async (hostname, ip) => {
    const { userAgent } = (0, context_1.getContext)();
    const [monikaInstance, osName] = await Promise.all([
        (0, exports.getMonikaInstance)(ip),
        getOSName(),
    ]);
    const monikaDetail = `${monikaInstance} - ${userAgent} - ${osName}`;
    return {
        subject: 'Monika terminated',
        body: `Monika is no longer running from ${monikaDetail}`,
        summary: `Monika is no longer running from ${monikaDetail}`,
        meta: {
            type: 'termination',
            time: new Date().toUTCString(),
            hostname,
            privateIpAddress: ip,
            publicIpAddress: public_ip_1.publicIpAddress,
            version: userAgent,
        },
    };
};
exports.getMessageForTerminate = getMessageForTerminate;
async function getOSName() {
    const osPlatform = (0, os_1.platform)();
    const isLinux = osPlatform === 'linux';
    if (isLinux) {
        try {
            const linuxDistro = await getLinuxDistro();
            // Checking again due to inconsistency of getos module return type
            if (linuxDistro.os !== 'linux') {
                return linuxDistro.os;
            }
            return `${linuxDistro?.dist || 'Unknown Linux Distribution'} - ${linuxDistro?.release || 'Unknown Release'}`.trim();
        }
        catch (error) {
            console.error('Cannot get Linux distribution:', error.message);
            return 'Unknown Linux Distribution - Unknown Release';
        }
    }
    return (0, os_name_1.default)();
}
exports.getOSName = getOSName;
//# sourceMappingURL=alert-message.js.map