"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_cron_1 = __importDefault(require("node-cron"));
const sinon_1 = __importDefault(require("sinon"));
const chai_1 = __importStar(require("chai"));
const chai_spies_1 = __importDefault(require("chai-spies"));
const schedule_notification_1 = require("./schedule-notification");
chai_1.default.use(chai_spies_1.default);
let cronScheduleStub;
let cronExpression;
let taskStopCalledTotal = 0;
describe('Schedule notification', () => {
    beforeEach(() => {
        cronScheduleStub = sinon_1.default
            .stub(node_cron_1.default, 'schedule')
            .callsFake((ce, _callback, _options) => {
            cronExpression = ce;
            return {
                stop() {
                    taskStopCalledTotal++;
                },
            };
        });
    });
    afterEach(() => {
        sinon_1.default.restore();
        cronExpression = '';
        taskStopCalledTotal = 0;
    });
    describe('Schedule summary notification', () => {
        it('should not schedule notification on Symon mode', () => {
            // act
            (0, schedule_notification_1.scheduleSummaryNotification)({
                config: { 'status-notification': '' },
                flags: { symonKey: 'secret-key', symonUrl: 'https://example.com' },
            });
            // assert
            sinon_1.default.assert.notCalled(cronScheduleStub);
        });
        it('should not schedule notification if status notification flag is false', () => {
            // act
            (0, schedule_notification_1.scheduleSummaryNotification)({
                config: { 'status-notification': '' },
                flags: { 'status-notification': 'false' },
            });
            // assert
            sinon_1.default.assert.notCalled(cronScheduleStub);
        });
        it('should schedule notification based on notification flag value', () => {
            // act
            (0, schedule_notification_1.scheduleSummaryNotification)({
                config: { 'status-notification': '0 0 0 0 0' },
                flags: {
                    'status-notification': '* * * * *',
                },
            });
            // assert
            sinon_1.default.assert.calledOnce(cronScheduleStub);
            (0, chai_1.expect)(cronExpression).eq('* * * * *');
        });
        it('should schedule notification based on notification config value', () => {
            // act
            (0, schedule_notification_1.scheduleSummaryNotification)({
                config: { 'status-notification': '0 0 0 0 0' },
                flags: {},
            });
            // assert
            sinon_1.default.assert.calledOnce(cronScheduleStub);
            (0, chai_1.expect)(cronExpression).eq('0 0 0 0 0');
        });
    });
    describe('Reset schedule notification', () => {
        it('should stop all running scheduled notification', () => {
            // act
            (0, schedule_notification_1.scheduleSummaryNotification)({
                config: { 'status-notification': '' },
                flags: {},
            });
            (0, schedule_notification_1.scheduleSummaryNotification)({
                config: { 'status-notification': '' },
                flags: {},
            });
            // arrange
            (0, chai_1.expect)(taskStopCalledTotal).eq(2);
        });
    });
});
//# sourceMappingURL=schedule-notification.test.js.map