"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const msw_1 = require("msw");
const node_1 = require("msw/node");
const sinon_1 = __importDefault(require("sinon"));
const mariadb_1 = __importDefault(require("mariadb"));
const mongodb_1 = require("mongodb");
const net_1 = __importDefault(require("net"));
const pg_1 = require("pg");
const redis = __importStar(require("redis"));
const _1 = require(".");
const probe_state_1 = require("../../utils/probe-state");
const context_1 = require("../../context");
const looper_1 = require("../../looper");
const history_1 = require("../logger/history");
let notificationAlert = {};
const server = (0, node_1.setupServer)(msw_1.http.get('https://example.com', () => new msw_1.HttpResponse(null, {
    status: 200,
})), msw_1.http.post('https://example.com/webhook', async ({ request }) => {
    const requestBody = (await request.json());
    if (requestBody?.body?.url) {
        notificationAlert[requestBody?.body?.url] = requestBody;
    }
    return new msw_1.HttpResponse(null, {
        status: 200,
    });
}));
describe('Base Probe processing', () => {
    before(async () => {
        server.listen();
        await (0, history_1.openLogfile)();
    });
    beforeEach(() => {
        (0, context_1.setContext)({ flags: { repeat: 1 } });
    });
    afterEach(() => {
        (0, context_1.resetContext)();
        notificationAlert = {};
        server.resetHandlers();
        sinon_1.default.restore();
    });
    after(async () => {
        server.close();
        await (0, history_1.closeLog)();
    });
    describe('Non HTTP Probe', () => {
        it('should probe MariaDB', async () => {
            // arrange
            const requestStub = sinon_1.default.stub(mariadb_1.default, 'createConnection').callsFake(async (_connectionUri) => ({
                async end() {
                    Promise.resolve();
                },
            }));
            const probes = [
                {
                    id: '1',
                    interval: 1,
                    mariadb: [
                        {
                            host: 'localhost',
                            port: 3306,
                            username: 'mariadb_user',
                            password: 'mariadb_password',
                            database: '',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should send incident notification for MariaDB probe', async () => {
            // arrange
            const probe = {
                id: '1c8QrZ',
                interval: 1,
                mariadb: [
                    {
                        host: 'localhost',
                        port: 3307,
                        username: 'mariadb_user',
                        password: 'mariadb_password',
                        database: '',
                    },
                ],
                alerts: [
                    {
                        id: 'Cqkjh',
                        ...looper_1.FAILED_REQUEST_ASSERTION,
                    },
                ],
            };
            (0, probe_state_1.initializeProbeStates)([probe]);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await (0, _1.doProbe)({
                probe,
                notifications: [
                    {
                        id: 'jFQBd',
                        data: { url: 'https://example.com/webhook' },
                        type: 'webhook',
                    },
                ],
                signal: new AbortController().signal,
            });
            // wait for random timeout
            await sleep(3 * seconds);
            // wait for send notification function to resolve
            await sleep(2 * seconds);
            // assert
            (0, test_1.expect)(notificationAlert?.[probe.id]?.body?.url).eq('1c8QrZ');
            (0, test_1.expect)(notificationAlert?.[probe.id]?.body?.alert).eq('');
            // restore
            sinon_1.default.stub(mariadb_1.default, 'createConnection').callsFake(async (_connectionUri) => ({
                async end() {
                    Promise.resolve();
                },
            }));
        }).timeout(10000);
        it('should send recovery notification for MariaDB probe', async () => {
            // simulate the incindent first by throwing on first call
            // then simulate recovery on second call
            const requestStub = sinon_1.default.stub(mariadb_1.default, 'createConnection');
            requestStub.onFirstCall().throws();
            requestStub.onSecondCall().callsFake(async (_connectionUri) => ({
                async end() {
                    Promise.resolve();
                },
            }));
            // repeat needs to be 0 so that monika can probe twice
            // where in the first time it will send incident notification
            // then in the second time it will send recovery notification
            (0, context_1.setContext)({
                ...(0, context_1.getContext)(),
                flags: { ...(0, context_1.getContext)().flags, repeat: 0 },
            });
            // arrange
            const probe = {
                id: '3ngd4',
                incidentThreshold: 1,
                interval: 1,
                mariadb: [
                    {
                        host: 'localhost',
                        port: 3308,
                        username: 'mariadb_user',
                        password: 'mariadb_password',
                        database: '',
                    },
                ],
                alerts: [
                    {
                        id: 'Cqkjh',
                        ...looper_1.FAILED_REQUEST_ASSERTION,
                    },
                ],
            };
            (0, probe_state_1.initializeProbeStates)([probe]);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await (0, _1.doProbe)({
                probe,
                notifications: [
                    {
                        id: 'jFQBd',
                        data: { url: 'https://example.com/webhook' },
                        type: 'webhook',
                    },
                ],
                signal: new AbortController().signal,
            });
            // gonna need to wait for a while until monika does the probing twice
            await sleep(7000);
            // assert
            sinon_1.default.assert.called(requestStub);
            (0, test_1.expect)(notificationAlert?.[probe.id]?.body?.url).eq('3ngd4');
            (0, test_1.expect)(notificationAlert?.[probe.id]?.body?.alert).eq('');
        }).timeout(15000);
        it('should probe MongoDB', async () => {
            // arrange
            const requestStub = sinon_1.default
                .stub(mongodb_1.MongoClient.prototype, 'connect')
                .resolves();
            sinon_1.default.stub(mongodb_1.MongoClient.prototype, 'on').resolves();
            sinon_1.default.stub(mongodb_1.MongoClient.prototype, 'db').callsFake(() => ({
                command: async () => ({ ok: 1 }),
            }));
            sinon_1.default.stub(mongodb_1.MongoClient.prototype, 'close').resolves();
            const probes = [
                {
                    id: 'FMqVc',
                    interval: 1,
                    mongo: [
                        {
                            host: 'localhost',
                            password: 'mongo_password',
                            port: '27017',
                            username: 'mongo_user',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe MongoDB with uri', async () => {
            // arrange
            const requestStub = sinon_1.default
                .stub(mongodb_1.MongoClient.prototype, 'connect')
                .resolves();
            sinon_1.default.stub(mongodb_1.MongoClient.prototype, 'on').resolves();
            sinon_1.default.stub(mongodb_1.MongoClient.prototype, 'db').callsFake(() => ({
                command: async () => ({ ok: 1 }),
            }));
            sinon_1.default.stub(mongodb_1.MongoClient.prototype, 'close').resolves();
            const probes = [
                {
                    id: '3cYAU',
                    interval: 1,
                    mongo: [
                        {
                            uri: 'mongodb://mongo_user:mongo_password@localhost:27018',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe MySQL', async () => {
            // arrange
            const requestStub = sinon_1.default.stub(mariadb_1.default, 'createConnection').callsFake(async (_connectionUri) => ({
                async end() {
                    Promise.resolve();
                },
            }));
            const probes = [
                {
                    id: 'YFwQH',
                    interval: 1,
                    mysql: [
                        {
                            host: 'localhost',
                            port: 3307,
                            username: 'mysql_user',
                            password: 'mysql_password',
                            database: '',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe PostgreSQL', async () => {
            // arrange
            const requestStub = sinon_1.default
                .stub(pg_1.Pool.prototype, 'connect')
                .callsFake(() => ({
                async query() { },
                async release() { },
            }));
            const probes = [
                {
                    id: 'LxMkT',
                    interval: 1,
                    postgres: [
                        {
                            database: 'postgres_db',
                            host: 'localhost',
                            password: 'postgres_password',
                            port: '5432',
                            username: 'postgres_user',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe PostgreSQL with uri', async () => {
            // arrange
            const requestStub = sinon_1.default
                .stub(pg_1.Pool.prototype, 'connect')
                .callsFake(() => ({
                async query() { },
                async release() { },
            }));
            const probes = [
                {
                    id: 'FAzEj',
                    interval: 1,
                    postgres: [
                        {
                            uri: 'postgres://postgres_user:postgres_password@localhost:5432/postgres_db',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe Redis', async () => {
            // arrange
            const requestStub = sinon_1.default.stub(redis, 'createClient').callsFake(() => ({
                async connect() { },
                on: () => '',
                ping: async () => 'PONG',
            }));
            const probes = [
                {
                    id: 'npTJ4',
                    interval: 1,
                    redis: [
                        {
                            host: 'localhost',
                            password: 'redis_password',
                            port: '6379',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe Redis with uri', async () => {
            // arrange
            const requestStub = sinon_1.default.stub(redis, 'createClient').callsFake(() => ({
                async connect() { },
                on: () => '',
                ping: async () => 'PONG',
            }));
            const probes = [
                {
                    id: '1',
                    interval: 1,
                    redis: [
                        {
                            uri: 'redis://:redis_password@localhost:6379',
                        },
                    ],
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
        it('should probe socket', async () => {
            const requestStub = sinon_1.default.stub(net_1.default, 'createConnection').callsFake(() => {
                let data;
                return {
                    write(d) {
                        data = d;
                    },
                    setTimeout(timeoutMs) {
                        return timeoutMs;
                    },
                    on(type, callback) {
                        switch (type) {
                            case 'data': {
                                callback(data);
                                break;
                            }
                            case 'close': {
                                callback();
                                break;
                            }
                            case 'timeout': {
                                callback();
                                break;
                            }
                            case 'error': {
                                callback(new Error('Stub Error'));
                                break;
                            }
                            default: {
                                break;
                            }
                        }
                    },
                };
            });
            const probes = [
                {
                    id: '3Ua7L',
                    interval: 1,
                    socket: {
                        host: 'localhost',
                        port: '8080',
                        data: 'some-data',
                    },
                },
            ];
            (0, probe_state_1.initializeProbeStates)(probes);
            // wait until the interval passed
            const seconds = 1000;
            await sleep(seconds);
            // act
            await Promise.all(probes.map((probe) => (0, _1.doProbe)({
                probe,
                notifications: [],
                signal: new AbortController().signal,
            })));
            // wait for random timeout
            await sleep(3 * seconds);
            // assert
            sinon_1.default.assert.calledOnce(requestStub);
        });
    });
});
function sleep(durationMs) {
    return new Promise((resolve) => {
        setTimeout(resolve, durationMs);
    });
}
//# sourceMappingURL=index.test.js.map