"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProber = exports.createProbers = void 0;
const http_1 = require("./http");
const mongo_1 = require("./mongo");
const mariadb_1 = require("./mariadb");
const icmp_1 = require("./icmp");
const postgres_1 = require("./postgres");
const redis_1 = require("./redis");
const socket_1 = require("./socket");
function createProbers(probeMetadata) {
    const { probeConfig } = probeMetadata;
    const result = [];
    if (probeConfig?.requests) {
        result.push(createProber(probeMetadata));
    }
    if (probeConfig?.mongo) {
        result.push(createProber(probeMetadata));
    }
    if (probeConfig?.mariadb || probeConfig?.mysql) {
        result.push(createProber(probeMetadata));
    }
    if (probeConfig?.postgres) {
        result.push(createProber(probeMetadata));
    }
    if (probeConfig?.redis) {
        result.push(createProber(probeMetadata));
    }
    if (probeConfig?.socket) {
        result.push(createProber(probeMetadata));
    }
    if (probeConfig?.ping) {
        result.push(createProber(probeMetadata));
    }
    return result;
}
exports.createProbers = createProbers;
function createProber(probeMetadata) {
    const { probeConfig } = probeMetadata;
    if (probeConfig?.requests) {
        return new http_1.HTTPProber(probeMetadata);
    }
    if (probeConfig?.mariadb || probeConfig?.mysql) {
        return new mariadb_1.MariaDBProber(probeMetadata);
    }
    if (probeConfig?.mongo) {
        return new mongo_1.MongoProber(probeMetadata);
    }
    if (probeConfig?.postgres) {
        return new postgres_1.PostgresProber(probeMetadata);
    }
    if (probeConfig?.redis) {
        return new redis_1.RedisProber(probeMetadata);
    }
    if (probeConfig?.socket) {
        return new socket_1.SocketProber(probeMetadata);
    }
    if (probeConfig?.ping) {
        return new icmp_1.PingProber(probeMetadata);
    }
    throw new Error('Unknown probe type');
}
exports.createProber = createProber;
//# sourceMappingURL=factory.js.map