"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.get = exports.put = void 0;
const ttlcache_1 = __importDefault(require("@isaacs/ttlcache"));
const crypto_1 = require("crypto");
const context_1 = require("../../../../context");
const pino_1 = require("../../../../utils/pino");
const ttlCache = new ttlcache_1.default();
const cacheHash = new Map();
function put(config, value) {
    const hash = getOrCreateHash(config);
    // manually set time-to-live for each cache entry
    // moved from "new TTLCache()" initialization above because corresponding flag is not yet parsed
    const minutes = 60000;
    const ttl = (0, context_1.getContext)().flags['ttl-cache'] * minutes;
    ttlCache.set(hash, value, { ttl });
}
exports.put = put;
function get(config) {
    const key = getOrCreateHash(config);
    const response = ttlCache.get(key);
    if ((0, context_1.getContext)().flags['verbose-cache']) {
        logVerbose({ response, key });
    }
    return response;
}
exports.get = get;
function getOrCreateHash(config) {
    const hash = cacheHash.get(config);
    if (hash) {
        return hash;
    }
    return (0, crypto_1.createHash)('SHA1').update(JSON.stringify(config)).digest('hex');
}
function logVerbose({ response, key }) {
    const time = new Date().toISOString();
    const shortHash = key.slice(Math.max(0, key.length - 7));
    const message = response ? 'Cache HIT' : 'Cache MISS';
    pino_1.log.info(`${time} - [${shortHash}] ${message}`);
}
//# sourceMappingURL=response-cache.js.map