"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const sinon_1 = __importDefault(require("sinon"));
const _1 = require(".");
const request_1 = require("../../../../interfaces/request");
const request = __importStar(require("./request"));
let pingRequestStub;
describe('Ping/ICMP Prober', () => {
    beforeEach(() => {
        pingRequestStub = sinon_1.default.stub(request, 'icmpRequest').callsFake(async (_options) => ({
            data: '',
            body: '',
            status: 0,
            result: request_1.probeRequestResult.failed,
            headers: '',
            responseTime: 0,
        }));
    });
    afterEach(() => {
        sinon_1.default.restore();
    });
    it('should have no result when input param is empty', async () => {
        // act
        const probeResults = await (0, _1.probePing)({ id: 'FgYCA', checkOrder: 1 });
        // assert
        (0, test_1.expect)(probeResults).deep.eq([]);
        sinon_1.default.assert.notCalled(pingRequestStub);
    });
    it('should probe using Ping', async () => {
        // arrange
        const pingParams = {
            id: 'test-ping',
            checkOrder: 1,
            pings: [
                {
                    uri: 'www.hyperjump.tech',
                },
            ],
        };
        // act
        const res = await (0, _1.probePing)(pingParams);
        // assert
        (0, test_1.expect)(res.length).deep.eq(1);
        sinon_1.default.assert.calledOnce(pingRequestStub);
    });
    it('array of 2 pings should work', async () => {
        // arrange
        const pingParams = {
            id: 'test-ping',
            checkOrder: 1,
            pings: [
                {
                    uri: 'www.hyperjump.tech',
                },
                {
                    uri: 'google.com',
                },
            ],
        };
        // act
        const res = await (0, _1.probePing)(pingParams);
        // assert
        (0, test_1.expect)(res.length).deep.eq(2);
        sinon_1.default.assert.calledTwice(pingRequestStub);
    });
    it('should result in an alert', async () => {
        // arrange
        sinon_1.default.restore();
        pingRequestStub = sinon_1.default.stub(request, 'icmpRequest').callsFake(async (_options) => ({
            data: '',
            body: '',
            status: 0,
            headers: '',
            responseTime: 0,
            result: request_1.probeRequestResult.failed,
        }));
        const pingParams = {
            id: 'test-ping',
            checkOrder: 1,
            pings: [
                {
                    uri: 'www.hyperjump.tech',
                },
            ],
        };
        // act
        const res = await (0, _1.probePing)(pingParams);
        // assert
        (0, test_1.expect)(res[0].isAlertTriggered).eq(true);
        sinon_1.default.assert.calledOnce(pingRequestStub);
    });
});
//# sourceMappingURL=index.test.js.map