"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2022 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.processICMPRequestResult = exports.icmpRequest = void 0;
const ping_1 = require("../../../../utils/ping");
const request_1 = require("../../../../interfaces/request");
const catch_error_handler_1 = require("../../../../utils/catch-error-handler");
async function icmpRequest(params) {
    const icmpResp = {
        isAlive: false,
        packetLoss: 100,
        average: 0,
    };
    const baseResponse = {
        data: '',
        body: '',
        status: 0,
        result: request_1.probeRequestResult.unknown,
        headers: '',
        responseTime: 0,
    };
    try {
        const resp = await (0, ping_1.sendPing)(params.host);
        icmpResp.host = resp.inputHost;
        icmpResp.average = resp.avg === 'unknown' ? 0 : resp.avg; // map response time to the average ping time
        icmpResp.isAlive = resp.alive;
        icmpResp.packetLoss = resp.packetLoss;
        icmpResp.numericHost = resp.numeric_host;
        icmpResp.output = resp.output;
        return processICMPRequestResult(icmpResp);
    }
    catch (error) {
        baseResponse.data = '';
        baseResponse.error = (0, catch_error_handler_1.getErrorMessage)(error);
    }
    return baseResponse;
}
exports.icmpRequest = icmpRequest;
// translates icmp specific response to base monika response
function processICMPRequestResult(params) {
    // build log message
    const aliveMsg = params.isAlive ? 'alive' : 'dead';
    const packetLossMsg = params.isAlive ? params.packetLoss : '100%';
    const msg = `PING:${aliveMsg} host:${params.host} avg:${params.average}ms packetLoss:${packetLossMsg}`;
    return {
        requestType: 'ICMP',
        data: params.output,
        status: params.isAlive ? 200 : 0,
        result: params.isAlive
            ? request_1.probeRequestResult.success
            : request_1.probeRequestResult.failed,
        body: msg,
        headers: {},
        responseTime: params.average || 0,
    };
}
exports.processICMPRequestResult = processICMPRequestResult;
//# sourceMappingURL=request.js.map