"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.probeMariaDB = exports.MariaDBProber = void 0;
const __1 = require("../");
const request_1 = require("../../../../interfaces/request");
const request_2 = require("./request");
class MariaDBProber extends __1.BaseProber {
    async probe({ incidentRetryAttempt }) {
        const result = await probeMariaDB({
            id: this.probeConfig.id,
            checkOrder: this.counter,
            mariaDB: this.probeConfig.mariadb,
            mysql: this.probeConfig.mysql,
        });
        this.processProbeResults(result, incidentRetryAttempt);
    }
    generateVerboseStartupMessage() {
        const { description, id, interval, name } = this.probeConfig;
        let result = `- Probe ID: ${id}
  Name: ${name}
  Description: ${description || '-'}
  Interval: ${interval}
`;
        result += '  Connection Details:';
        result += this.getConnectionDetails();
        return result;
    }
    getConnectionDetails() {
        const connectionDetails = this.probeConfig?.mariadb || this.probeConfig?.mysql;
        return (connectionDetails
            ?.map((db) => `
    Host: ${db.host}
    Port: ${db.port}
    Database: ${db.database}
    Username: ${db.username}
`)
            .join('\n') || '');
    }
}
exports.MariaDBProber = MariaDBProber;
async function probeMariaDB({ id, checkOrder, mariaDB, mysql, }) {
    const databases = mariaDB ?? mysql;
    const databaseText = mariaDB ? 'mariadb' : 'mysql';
    const probeResults = [];
    if (!databases) {
        return probeResults;
    }
    for await (const { host, port, database, username, password } of databases) {
        const requestResponse = await (0, request_2.mariaRequest)({
            host,
            port,
            database,
            username,
            password,
        });
        const { body, responseTime, result } = requestResponse;
        const isAlertTriggered = result !== request_1.probeRequestResult.success;
        const timeNow = new Date().toISOString();
        const logMessage = `${timeNow} ${checkOrder} id:${id} ${databaseText}:${host}:${port} ${responseTime}ms msg:${body}`;
        probeResults.push({ isAlertTriggered, logMessage, requestResponse });
    }
    return probeResults;
}
exports.probeMariaDB = probeMariaDB;
//# sourceMappingURL=index.js.map