"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.mariaRequest = void 0;
const catch_error_handler_1 = require("../../../../utils/catch-error-handler");
const request_1 = require("../../../../interfaces/request");
const date_fns_1 = require("date-fns");
const mariadb_1 = require("mariadb");
async function mariaRequest(params) {
    const baseResponse = {
        requestType: 'mariadb',
        data: '',
        body: '',
        status: 0,
        result: request_1.probeRequestResult.unknown,
        headers: '',
        responseTime: 0,
    };
    const startTime = new Date();
    let isConnected = false;
    try {
        isConnected = await checkConnection({
            host: params.host,
            port: params.port,
            username: params.username,
            password: params.password,
            database: params.database,
        });
    }
    catch (error) {
        baseResponse.body = '';
        baseResponse.error = (0, catch_error_handler_1.getErrorMessage)(error);
        baseResponse.result = request_1.probeRequestResult.failed;
        isConnected = false;
    }
    const endTime = new Date();
    const duration = (0, date_fns_1.differenceInMilliseconds)(endTime, startTime);
    if (isConnected) {
        baseResponse.responseTime = duration;
        baseResponse.body = 'database ok';
        baseResponse.status = 200;
        baseResponse.result = request_1.probeRequestResult.success;
    }
    return baseResponse;
}
exports.mariaRequest = mariaRequest;
async function checkConnection(params) {
    const client = await (0, mariadb_1.createConnection)({
        host: params?.host,
        port: params?.port,
        user: params?.username,
        password: params?.password,
        database: params?.database,
        allowPublicKeyRetrieval: true,
    });
    await client.end();
    return true;
}
//# sourceMappingURL=request.js.map