"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.probeMongo = exports.MongoProber = void 0;
const mongodbURI = __importStar(require("mongodb-uri"));
const __1 = require("..");
const request_1 = require("../../../../interfaces/request");
const request_2 = require("./request");
class MongoProber extends __1.BaseProber {
    async probe({ incidentRetryAttempt }) {
        if (!this.probeConfig.mongo) {
            throw new Error(`Mongo configuration is empty. Probe ID: ${this.probeConfig.id}`);
        }
        const result = await probeMongo({
            id: this.probeConfig.id,
            checkOrder: this.counter,
            mongo: this.probeConfig.mongo,
        });
        this.processProbeResults(result, incidentRetryAttempt);
    }
    generateVerboseStartupMessage() {
        const { description, id, interval, name } = this.probeConfig;
        let result = `- Probe ID: ${id}
  Name: ${name}
  Description: ${description || '-'}
  Interval: ${interval}
`;
        result += '  Connection Details:';
        result += this.getConnectionDetails();
        return result;
    }
    getConnectionDetails() {
        return (this.probeConfig.mongo
            ?.map((db) => {
            if (db.uri) {
                return `
    URI: ${db.uri}
`;
            }
            return `
    Host: ${db.host}
    Port: ${db.port}
    Username: ${db.username}
`;
        })
            .join('\n') || '');
    }
}
exports.MongoProber = MongoProber;
async function probeMongo({ id, checkOrder, mongo, }) {
    const probeResults = [];
    for await (const mongoDB of mongo) {
        const { host, password, port, uri, username } = getMongoConnectionDetails(mongoDB);
        const requestResponse = await (0, request_2.mongoRequest)({
            uri,
            host,
            port,
            username,
            password,
        });
        const { body, responseTime, result } = requestResponse;
        const isAlertTriggered = result !== request_1.probeRequestResult.success;
        const timeNow = new Date().toISOString();
        const logMessage = `${timeNow} ${checkOrder} id:${id} mongo:${host}:${port} ${responseTime}ms msg:${body}`;
        probeResults.push({ isAlertTriggered, logMessage, requestResponse });
    }
    return probeResults;
}
exports.probeMongo = probeMongo;
function getMongoConnectionDetails({ host, password, port, uri, username, }) {
    if (!uri) {
        return { host, password, port, uri, username };
    }
    const parsed = mongodbURI.parse(uri);
    const { hosts, password: parsedPassword, username: parsedUsername } = parsed;
    return {
        host: hosts[0].host,
        password: parsedPassword,
        port: hosts[0].port,
        uri,
        username: parsedUsername,
    };
}
//# sourceMappingURL=index.js.map