"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const sinon_1 = __importDefault(require("sinon"));
const _1 = require(".");
const request_1 = require("../../../../interfaces/request");
const request = __importStar(require("./request"));
let mongoRequestStub;
describe('MongoDB Prober', () => {
    beforeEach(() => {
        mongoRequestStub = sinon_1.default.stub(request, 'mongoRequest').callsFake(async (_options) => ({
            requestType: 'mongo',
            data: '',
            body: '',
            status: 200,
            headers: '',
            responseTime: 0,
            result: request_1.probeRequestResult.failed,
        }));
    });
    afterEach(() => {
        sinon_1.default.restore();
    });
    it('should probe using MongoDB', async () => {
        // arrange
        const probeParams = {
            id: 'FgYCA',
            checkOrder: 1,
            mongo: [
                {
                    host: 'localhost',
                    port: 2701,
                    username: 'monika_username',
                    password: 'monika_password',
                },
            ],
        };
        // act
        const probeResults = await (0, _1.probeMongo)(probeParams);
        // assert
        (0, test_1.expect)(probeResults.length).deep.eq(1);
        (0, test_1.expect)(probeResults[0].logMessage).include('mongo');
        sinon_1.default.assert.calledOnce(mongoRequestStub);
    });
    it('should probe multiple probes', async () => {
        // arrange
        const probeParams = {
            id: 'wTBPV',
            checkOrder: 1,
            mongo: [
                {
                    host: 'localhost',
                    port: 2701,
                    database: 'monika_database',
                    username: 'monika_username',
                    password: 'monika_password',
                },
                {
                    host: 'localhost',
                    port: 2701,
                    database: 'monika_database_staging',
                    username: 'monika_username_staging',
                    password: 'monika_password_staging',
                },
            ],
        };
        // act
        const probeResults = await (0, _1.probeMongo)(probeParams);
        // assert
        (0, test_1.expect)(probeResults.length).eq(2);
        sinon_1.default.assert.calledTwice(mongoRequestStub);
    });
    it('should return alert triggered', async () => {
        // arrange
        sinon_1.default.restore();
        mongoRequestStub = sinon_1.default.stub(request, 'mongoRequest').callsFake(async (_options) => ({
            requestType: 'mongo',
            data: '',
            body: '',
            status: 0,
            headers: '',
            responseTime: 0,
            result: request_1.probeRequestResult.failed,
        }));
        const probeParams = {
            id: 'wTBPV',
            checkOrder: 1,
            mongo: [
                {
                    host: 'localhost',
                    port: 2701,
                    username: 'monika_username',
                    password: 'monika_password',
                },
            ],
        };
        // act
        const probeResults = await (0, _1.probeMongo)(probeParams);
        // assert
        (0, test_1.expect)(probeResults[0].isAlertTriggered).eq(true);
        sinon_1.default.assert.calledOnce(mongoRequestStub);
    });
    it('should use mongoDB uri', async () => {
        // arrange
        sinon_1.default.restore();
        mongoRequestStub = sinon_1.default.stub(request, 'mongoRequest').callsFake(async (_options) => ({
            requestType: 'mongo',
            data: '',
            body: '',
            status: 0,
            headers: '',
            responseTime: 0,
            result: request_1.probeRequestResult.failed,
        }));
        const probeParams = {
            id: 'wTBPV',
            checkOrder: 1,
            mongo: [
                {
                    host: 'localhost',
                    port: 2701,
                    username: 'monika_username',
                    password: 'monika_password',
                    uri: 'mongodb://monika_username:monika_password@localhost:2701',
                },
            ],
        };
        // act
        const probeResults = await (0, _1.probeMongo)(probeParams);
        // assert
        (0, test_1.expect)(probeResults[0].isAlertTriggered).eq(true);
        sinon_1.default.assert.calledOnce(mongoRequestStub);
    });
});
//# sourceMappingURL=index.test.js.map