"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.probeSocket = exports.SocketProber = void 0;
const __1 = require("..");
const request_1 = require("../../../../interfaces/request");
const request_2 = require("./request");
class SocketProber extends __1.BaseProber {
    async probe({ incidentRetryAttempt }) {
        if (!this.probeConfig.socket) {
            throw new Error(`Socket configuration is empty. Probe ID: ${this.probeConfig.id}`);
        }
        const result = await probeSocket({
            id: this.probeConfig.id,
            checkOrder: this.counter,
            socket: this.probeConfig.socket,
        });
        this.processProbeResults(result, incidentRetryAttempt);
    }
    generateVerboseStartupMessage() {
        const { description, id, interval, name } = this.probeConfig;
        let result = `- Probe ID: ${id}
  Name: ${name}
  Description: ${description || '-'}
  Interval: ${interval}
`;
        result += '  Connection Details:';
        result += this.getConnectionDetails();
        return result;
    }
    getConnectionDetails() {
        return `
    Host: ${this.probeConfig?.socket?.host}
    Port: ${this.probeConfig?.socket?.port}
    Username: ${this.probeConfig?.socket?.data}
`;
    }
}
exports.SocketProber = SocketProber;
async function probeSocket({ id, checkOrder, socket, }) {
    const { data, host, port } = socket;
    const url = `${host}:${port}`;
    const requestResponse = await (0, request_2.tcpRequest)({ host, port, data });
    const { body, responseTime, result } = requestResponse;
    const isAlertTriggered = result !== request_1.probeRequestResult.success;
    const timeNow = new Date().toISOString();
    const logMessage = `${timeNow} ${checkOrder} id:${id} tcp:${url} ${responseTime}ms msg:${body}`;
    return [{ isAlertTriggered, logMessage, requestResponse }];
}
exports.probeSocket = probeSocket;
//# sourceMappingURL=index.js.map