"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.printSummary = void 0;
const promises_1 = require("node:fs/promises");
const node_os_1 = require("node:os");
const context_1 = require("../context");
const ip_1 = __importDefault(require("../utils/ip"));
const pino_1 = require("../utils/pino");
const public_ip_1 = require("../utils/public-ip");
const history_1 = require("./logger/history");
// printSummary gathers and print some stats
async function printSummary() {
    await (0, history_1.openLogfile)();
    const [pidFileContent, summary] = await Promise.all([
        readPidFile(),
        (0, history_1.getSummary)(),
    ]);
    const { monikaConfigFile, monikaNotifs, monikaPid, monikaProbes, monikaStartTime, } = pidFileContent;
    const { numberOfIncidents, numberOfRecoveries, numberOfSentNotifications } = summary;
    const uptime = getDaysHours(monikaStartTime);
    const host = `${(0, node_os_1.hostname)()} (${[public_ip_1.publicIpAddress, (0, ip_1.default)()]
        .filter(Boolean)
        .join('/')})`;
    pino_1.log.info(`Monika Summary

Monika process id\t: ${monikaPid}
Active config file\t: ${monikaConfigFile}
Probes set\t\t: ${monikaProbes}
Notifications set\t: ${monikaNotifs}
Number of incidents\t: ${numberOfIncidents} in last 24hr
Number of recoveries\t: ${numberOfRecoveries} in last 24hr
Number of notifications\t: ${numberOfSentNotifications} in last 24h

Up time\t\t: ${uptime}
Running on\t: ${host}
App version\t: ${(0, context_1.getContext)().userAgent}`);
}
exports.printSummary = printSummary;
// getDaysHours breaks down the date into days  hours minute string
function getDaysHours(startTime) {
    let duration = Math.abs((Date.now() - new Date(startTime).getTime()) / 1000);
    const numDays = Math.floor(duration / 86400);
    duration -= numDays * 86400; // get the remaining hours
    const numHours = Math.floor(duration / 3600) % 24;
    duration -= numHours * 3600; // get the remaining minutes
    const numMinutes = Math.floor(duration / 60) % 60;
    const numSeconds = Math.floor(duration - numMinutes * 60);
    return `${numDays} days, ${numHours} hours, ${numMinutes} minutes, ${numSeconds} seconds`;
}
// readsPidFile reads a local monika.pid file and returns the information in it
async function readPidFile() {
    const fileContent = await (0, promises_1.readFile)('monika.pid', { encoding: 'utf8' });
    return JSON.parse(fileContent);
}
//# sourceMappingURL=summary.js.map