"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHostname = exports.checkTLS = void 0;
const ssl_checker_1 = __importDefault(require("ssl-checker"));
async function checkTLS(domain, 
// default expiry threshold is 30 days
expiryThreshold = 30) {
    const hostname = getHostname(domain);
    const requestOptions = getRequestOptions(domain);
    const { valid, validTo, daysRemaining } = await (0, ssl_checker_1.default)(hostname, requestOptions);
    if (!valid) {
        throw new Error(`${hostname} security certificate has expired at ${validTo}!`);
    }
    if (daysRemaining <= expiryThreshold) {
        throw new Error(`${hostname} security certificate will expire at ${validTo}!`);
    }
    return null;
}
exports.checkTLS = checkTLS;
function getHostname(domain) {
    if (typeof domain === 'string') {
        return domain;
    }
    return domain.domain;
}
exports.getHostname = getHostname;
function getRequestOptions(domain) {
    if (typeof domain === 'string') {
        return undefined;
    }
    return domain?.options;
}
//# sourceMappingURL=index.js.map