"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeFlags = exports.flags = exports.monikaFlagsDefaultValue = exports.SYMON_API_VERSION = void 0;
const node_fs_1 = __importDefault(require("node:fs"));
const node_path_1 = __importDefault(require("node:path"));
const core_1 = require("@oclif/core");
var SYMON_API_VERSION;
(function (SYMON_API_VERSION) {
    SYMON_API_VERSION["v1"] = "v1";
    SYMON_API_VERSION["v2"] = "v2";
})(SYMON_API_VERSION || (exports.SYMON_API_VERSION = SYMON_API_VERSION = {}));
const DEFAULT_CONFIG_INTERVAL_SECONDS = 900;
const DEFAULT_SYMON_REPORT_INTERVAL_MS = 10000;
exports.monikaFlagsDefaultValue = {
    'compact-probes': false,
    config: getDefaultConfig(),
    'config-filename': 'monika.yml',
    'config-interval': DEFAULT_CONFIG_INTERVAL_SECONDS,
    'create-config': false,
    flush: false,
    'follow-redirects': 21,
    force: false,
    ignoreInvalidTLS: false,
    'keep-verbose-logs': false,
    logs: false,
    'native-fetch': false,
    'one-probe': false,
    output: 'monika.yml',
    repeat: 0,
    retryInitialDelayMs: 2000,
    retryMaxDelayMs: 30000,
    'skip-start-message': false,
    stun: 20,
    summary: false,
    'symon-api-version': SYMON_API_VERSION.v1,
    symonGetProbesIntervalMs: 60000,
    symonReportInterval: DEFAULT_SYMON_REPORT_INTERVAL_MS,
    symonReportLimit: 100,
    'user-agent': undefined,
    'ttl-cache': 0,
    verbose: false,
    'verbose-cache': false,
    version: false,
};
function getDefaultConfig() {
    const filesArray = node_fs_1.default.readdirSync(node_path_1.default.dirname('../'));
    const monikaDotJsonFile = filesArray.find((x) => x === 'monika.json');
    const monikaDotYamlFile = filesArray.find((x) => x === 'monika.yml' || x === 'monika.yaml');
    const defaultConfig = monikaDotYamlFile || monikaDotJsonFile;
    return defaultConfig ? [defaultConfig] : [];
}
exports.flags = {
    'auto-update': core_1.Flags.string({
        description: 'Enable auto-update for Monika. Available options: major, minor, patch. This will make Monika terminate itself on successful update but does not restart',
    }),
    'compact-probes': core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue['compact-probes'],
        description: 'Compact probes with the same request configuration. This will not merge probes with request chaining.',
    }),
    config: core_1.Flags.string({
        char: 'c',
        default: exports.monikaFlagsDefaultValue.config,
        description: 'JSON configuration filename or URL. If none is supplied, will look for monika.yml in the current directory',
        env: 'MONIKA_JSON_CONFIG',
        multiple: true,
    }),
    'config-filename': core_1.Flags.string({
        default: exports.monikaFlagsDefaultValue['config-filename'],
        dependsOn: ['config'],
        description: 'The configuration filename for config file created if there is no config file found ',
    }),
    'config-interval': core_1.Flags.integer({
        default: exports.monikaFlagsDefaultValue['config-interval'],
        dependsOn: ['config'],
        description: 'The interval (in seconds) for periodic config checking if url is used as config source',
    }),
    'create-config': core_1.Flags.boolean({
        description: 'Create config from HAR (-H), postman (-p), insomnia (-I), sitemap (--sitemap), textfile (--text) export file, or open Monika Configuration Generator using default browser',
        default: exports.monikaFlagsDefaultValue['create-config'],
    }),
    flush: core_1.Flags.boolean({
        description: 'Flush logs',
        default: exports.monikaFlagsDefaultValue.flush,
    }),
    'follow-redirects': core_1.Flags.integer({
        default: exports.monikaFlagsDefaultValue['follow-redirects'],
        description: 'Monika will follow redirects as many times as the specified value here. By default, Monika will follow redirects once. To disable redirects following, set the value to zero.',
    }),
    force: core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue.force,
        description: 'Force commands with a yes whenever Y/n is prompted.',
    }),
    har: core_1.Flags.string({
        char: 'H',
        description: 'Run Monika using a HAR file',
        exclusive: ['postman', 'insomnia', 'sitemap', 'text'],
    }),
    help: core_1.Flags.help({ char: 'h' }),
    id: core_1.Flags.string({
        char: 'i',
        description: 'Define specific probe ids to run',
    }),
    ignoreInvalidTLS: core_1.Flags.boolean({
        description: 'Configures whether HTTPS requests should ignore invalid certificates',
        default: exports.monikaFlagsDefaultValue.ignoreInvalidTLS,
    }),
    insomnia: core_1.Flags.string({
        char: 'I',
        description: 'Run Monika using an Insomnia json/yaml file',
        exclusive: ['har', 'postman', 'sitemap', 'text'],
    }),
    'keep-verbose-logs': core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue['keep-verbose-logs'],
        description: 'Store all requests logs to database',
    }),
    logs: core_1.Flags.boolean({
        char: 'l',
        description: 'Print all logs.',
        default: exports.monikaFlagsDefaultValue.logs,
    }),
    'native-fetch': core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue['native-fetch'],
        description: 'Use native fetch Node.js API instead of Axios for HTTP client',
    }),
    'one-probe': core_1.Flags.boolean({
        dependsOn: ['sitemap'],
        description: 'One Probe',
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'Write monika config file to this file',
        default: exports.monikaFlagsDefaultValue.output,
    }),
    postman: core_1.Flags.string({
        char: 'p',
        description: 'Run Monika using a Postman json file.',
        exclusive: ['har', 'insomnia', 'sitemap', 'text'],
    }),
    prometheus: core_1.Flags.integer({
        description: 'Specifies the port the Prometheus metric server is listening on. e.g., 3001. (EXPERIMENTAL)',
        exclusive: ['r'],
    }),
    repeat: core_1.Flags.integer({
        char: 'r',
        default: exports.monikaFlagsDefaultValue.repeat,
        description: 'Repeats the test run n times',
    }),
    retryInitialDelayMs: core_1.Flags.integer({
        default: exports.monikaFlagsDefaultValue.retryInitialDelayMs,
        description: `The initial, first delay of the backoff retry when probe request is failed, in milliseconds. Defaults to ${exports.monikaFlagsDefaultValue.retryInitialDelayMs}ms`,
    }),
    retryMaxDelayMs: core_1.Flags.integer({
        default: exports.monikaFlagsDefaultValue.retryMaxDelayMs,
        description: `Maximum backoff retry delay, in milliseconds. Defaults to ${exports.monikaFlagsDefaultValue.retryMaxDelayMs}ms.`,
    }),
    sentryDSN: core_1.Flags.string({
        description: 'DSN for Sentry',
    }),
    sitemap: core_1.Flags.string({
        description: 'Run Monika using a Sitemap xml file.',
        exclusive: ['har', 'insomnia', 'postman', 'text'],
    }),
    'skip-start-message': core_1.Flags.boolean({
        description: 'Skip Monika startup message',
    }),
    'status-notification': core_1.Flags.string({
        description: 'Cron syntax for status notification schedule',
    }),
    stun: core_1.Flags.integer({
        char: 's',
        default: exports.monikaFlagsDefaultValue.stun,
        description: 'Interval in seconds to check STUN server',
    }),
    summary: core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue.summary,
        description: 'Display a summary of monika running stats',
    }),
    'symon-api-version': core_1.Flags.custom({
        default: exports.monikaFlagsDefaultValue['symon-api-version'],
        description: 'Symon API version to use. Available options: v1, v2. Default: v1',
        options: [SYMON_API_VERSION.v1, SYMON_API_VERSION.v2],
    })(),
    symonKey: core_1.Flags.string({
        dependsOn: ['symonUrl'],
        description: 'API Key for Symon',
    }),
    symonGetProbesIntervalMs: core_1.Flags.integer({
        default: exports.monikaFlagsDefaultValue.symonGetProbesIntervalMs,
        description: `To determine how often Monika sends a request to Symon to get probe data, in milliseconds. Defaults to ${exports.monikaFlagsDefaultValue.symonGetProbesIntervalMs}ms`,
    }),
    symonLocationId: core_1.Flags.string({
        dependsOn: ['symonKey', 'symonUrl'],
        description: 'Location ID for Symon (optional)',
    }),
    symonMonikaId: core_1.Flags.string({
        dependsOn: ['symonKey', 'symonUrl'],
        description: 'Monika ID for Symon (optional)',
    }),
    symonReportInterval: core_1.Flags.integer({
        dependsOn: ['symonKey', 'symonUrl'],
        description: 'Interval for reporting to Symon in milliseconds (optional)',
    }),
    symonReportLimit: core_1.Flags.integer({
        dependsOn: ['symonKey', 'symonUrl'],
        description: 'Data limit to be reported to Symon (optional)',
    }),
    symonUrl: core_1.Flags.string({
        dependsOn: ['symonKey'],
        description: 'URL of Symon',
        hidden: false,
    }),
    text: core_1.Flags.string({
        description: 'Run Monika using a Simple text file',
        exclusive: ['postman', 'insomnia', 'sitemap', 'har'],
    }),
    'ttl-cache': core_1.Flags.integer({
        description: 'Enables time-to-live for in-memory (HTTP) cache entries in minutes',
        default: exports.monikaFlagsDefaultValue['ttl-cache'],
    }),
    'user-agent': core_1.Flags.string({
        default: exports.monikaFlagsDefaultValue['user-agent'],
        description: 'User agent to use for probing, defaults to monika/{current Monika version}',
    }),
    verbose: core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue.verbose,
        description: 'Show verbose log messages',
    }),
    'verbose-cache': core_1.Flags.boolean({
        default: exports.monikaFlagsDefaultValue.verbose,
        description: 'Show cache hit / miss messages to log',
    }),
    version: core_1.Flags.boolean({ char: 'v', description: 'show CLI version' }),
};
function sanitizeFlags(flags) {
    return { ...exports.monikaFlagsDefaultValue, ...flags };
}
exports.sanitizeFlags = sanitizeFlags;
//# sourceMappingURL=flag.js.map