"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkDBSize = void 0;
const node_path_1 = require("node:path");
const promises_1 = require("node:fs/promises");
const config_1 = require("../components/config");
const history_1 = require("../components/logger/history");
const dbPath = (0, node_path_1.resolve)(process.cwd(), 'monika-logs.db');
async function checkDBSize() {
    await deleteData((0, config_1.getValidatedConfig)());
}
exports.checkDBSize = checkDBSize;
async function deleteData(config) {
    const { db_limit: dbLimit } = config;
    if (!dbLimit?.max_db_size || !dbLimit.deleted_data) {
        return;
    }
    const { deleted_data: deletedData, max_db_size: maxDbSize } = dbLimit;
    const { size } = await (0, promises_1.stat)(dbPath);
    if (size > maxDbSize) {
        const { probeRequestIds, probeIds } = await (0, history_1.deleteFromProbeRequests)(deletedData);
        await (0, history_1.deleteFromNotifications)(probeIds);
        await (0, history_1.deleteFromAlerts)(probeRequestIds);
        deleteData(config); // recursive until reached expected file size
    }
}
//# sourceMappingURL=check-database.js.map