"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../components/config");
const watcher_1 = require("../components/config/watcher");
const history_1 = require("../components/logger/history");
const context_1 = require("../context");
const events_1 = __importDefault(require("../events"));
const tls_check_1 = require("../jobs/tls-check");
const looper_1 = require("../looper");
const prometheus_1 = require("../plugins/metrics/prometheus");
const events_2 = require("../utils/events");
const jobs_1 = require("./jobs");
const updater_1 = require("../plugins/updater");
// import the subscriber file to activate the event emitter subscribers
require("../events/subscribers/application");
require("../events/subscribers/probe");
async function init(flags, cliConfig) {
    await (0, history_1.openLogfile)();
    // check if connected to STUN Server and getting the public IP in the same time
    await (0, looper_1.loopCheckSTUNServer)(flags.stun);
    // run auto-updater
    if (flags['auto-update']) {
        await (0, updater_1.enableAutoUpdate)(cliConfig, flags['auto-update']);
    }
    // start Promotheus server
    if (flags.prometheus) {
        initPrometheus(flags.prometheus);
    }
    if (!(0, config_1.isSymonModeFrom)(flags)) {
        (0, watcher_1.watchConfigChanges)();
        // check TLS when Monika starts
        (0, tls_check_1.tlsChecker)();
        if (!(0, context_1.getContext)().isTest) {
            // load cron jobs
            (0, jobs_1.jobsLoader)();
        }
    }
}
exports.default = init;
function initPrometheus(prometheusPort) {
    const eventEmitter = (0, events_2.getEventEmitter)();
    const { collectProbeTotal, collectProbeRequestMetrics, collectTriggeredAlert, decrementProbeRunningTotal, incrementProbeRunningTotal, resetProbeRunningTotal, collectProbeStatus, collectNotificationSentMetrics, } = new prometheus_1.PrometheusCollector();
    // collect prometheus metrics
    eventEmitter.on(events_1.default.config.sanitized, (probes) => {
        collectProbeTotal(probes.length);
    });
    eventEmitter.on(events_1.default.probe.response.received, collectProbeRequestMetrics);
    eventEmitter.on(events_1.default.probe.alert.triggered, collectTriggeredAlert);
    eventEmitter.on(events_1.default.probe.ran, incrementProbeRunningTotal);
    eventEmitter.on(events_1.default.probe.finished, decrementProbeRunningTotal);
    eventEmitter.on(events_1.default.config.updated, resetProbeRunningTotal);
    eventEmitter.on(events_1.default.probe.status.changed, collectProbeStatus);
    eventEmitter.on(events_1.default.notifications.sent, collectNotificationSentMetrics);
    (0, prometheus_1.startPrometheusMetricsServer)(prometheusPort);
}
//# sourceMappingURL=index.js.map