"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.jobsLoader = void 0;
const node_cron_1 = require("node-cron");
const tls_check_1 = require("../jobs/tls-check");
const check_database_1 = require("../jobs/check-database");
const config_1 = require("../components/config");
const catch_error_handler_1 = require("../utils/catch-error-handler");
const pino_1 = require("../utils/pino");
function jobsLoader() {
    // schedule TLS checker every day at 00:00
    (0, node_cron_1.schedule)('0 0 * * *', tls_check_1.tlsChecker);
    // schedule database size check
    const config = (0, config_1.getValidatedConfig)();
    if (config?.db_limit && config?.db_limit.cron_schedule) {
        (0, node_cron_1.schedule)(config.db_limit.cron_schedule, () => (0, check_database_1.checkDBSize)().catch((error) => pino_1.log.error((0, catch_error_handler_1.getErrorMessage)(error))));
    }
}
exports.jobsLoader = jobsLoader;
//# sourceMappingURL=jobs.js.map