"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const request_1 = require("../../../interfaces/request");
const collector_1 = require("./collector");
describe('Prometheus collector', () => {
    describe('Collect probe request metrics', () => {
        it('should not throw', () => {
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectProbeTotal(10)).not.to.throw();
        });
    });
    describe('Collect probe request metrics', () => {
        it('should not throw', () => {
            // arrange
            const probeResult = {
                probe: {
                    id: '',
                    name: '',
                    interval: 0,
                    requests: [
                        {
                            url: '',
                            body: '',
                            followRedirects: 21,
                            timeout: 0,
                        },
                    ],
                    alerts: [
                        {
                            id: 'fKBzx',
                            assertion: '',
                            message: '',
                        },
                    ],
                },
                requestIndex: 0,
                response: {
                    data: '',
                    body: '',
                    status: 0,
                    headers: '',
                    responseTime: 0,
                    result: request_1.probeRequestResult.failed,
                },
            };
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectProbeRequestMetrics(probeResult)).not.to.throw();
        });
        it('should not throw with empty request', () => {
            // arrange
            const probeResult = {
                probe: {
                    id: '',
                    name: '',
                    interval: 0,
                    requests: [],
                    alerts: [{ id: 'fKBzx', assertion: '', message: '' }],
                },
                requestIndex: 0,
                response: {
                    data: '',
                    body: '',
                    status: 0,
                    headers: '',
                    responseTime: 0,
                    result: request_1.probeRequestResult.failed,
                },
            };
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectProbeRequestMetrics(probeResult)).not.to.throw();
        });
        it('should not throw with undefined request', () => {
            // arrange
            const probeResult = {
                probe: {
                    id: '',
                    name: '',
                    interval: 0,
                    alerts: [
                        {
                            assertion: '',
                        },
                    ],
                },
                requestIndex: 0,
                response: {
                    data: '',
                    body: '',
                    status: 0,
                    headers: '',
                    responseTime: 0,
                },
            };
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectProbeRequestMetrics(probeResult)).not.to.throw();
        });
    });
    describe('Collect triggered allert metrics', () => {
        it('should not throw', () => {
            // arrange
            const probeResult = {
                probe: {
                    id: '',
                    name: '',
                    interval: 0,
                    requests: [
                        {
                            url: '',
                            body: '',
                            followRedirects: 21,
                            timeout: 0,
                        },
                    ],
                    alerts: [{ id: 'fKBzx', assertion: '', message: '' }],
                },
                requestIndex: 0,
                alertQuery: '',
            };
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectTriggeredAlert(probeResult)).not.to.throw();
        });
        it('should not throw with empty request', () => {
            // arrange
            const probeResult = {
                probe: {
                    id: '',
                    name: '',
                    interval: 0,
                    requests: [],
                    alerts: [{ id: 'fKBzx', assertion: '', message: '' }],
                },
                requestIndex: 0,
                alertQuery: '',
            };
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectTriggeredAlert(probeResult)).not.to.throw();
        });
        it('should not throw with undefined request', () => {
            // arrange
            const probeResult = {
                probe: {
                    id: '',
                    name: '',
                    interval: 0,
                    alerts: [
                        {
                            assertion: '',
                        },
                    ],
                },
                requestIndex: 0,
                alertQuery: '',
            };
            // act
            const prometheusCollector = new collector_1.PrometheusCollector();
            // assert
            (0, test_1.expect)(() => prometheusCollector.collectTriggeredAlert(probeResult)).not.to.throw();
        });
    });
});
//# sourceMappingURL=collector.test.js.map