"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.startPrometheusMetricsServer = void 0;
const express_1 = __importDefault(require("express"));
const helmet_1 = __importDefault(require("helmet"));
const prom_client_1 = require("prom-client");
const pino_1 = require("../../../utils/pino");
const catch_error_handler_1 = require("../../../utils/catch-error-handler");
function startPrometheusMetricsServer(port) {
    const app = (0, express_1.default)();
    // security middleware
    app.use((0, helmet_1.default)());
    app.use((req, res, next) => {
        if (req.method !== 'GET') {
            return res.status(405).end();
        }
        next();
    });
    app.get('/metrics', async (_, res) => {
        try {
            const prometheusMetrics = await prom_client_1.register.metrics();
            res
                .status(200)
                .header('Content-Type', prom_client_1.register.contentType)
                .end(prometheusMetrics);
        }
        catch (error) {
            res.status(500).json({ message: (0, catch_error_handler_1.getErrorMessage)(error) });
        }
    });
    app.listen(port, () => {
        pino_1.log.info(`You can scrape Prometheus metrics from http://localhost:${port}/metrics`);
    });
}
exports.startPrometheusMetricsServer = startPrometheusMetricsServer;
//# sourceMappingURL=publisher.js.map