"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initSentry = void 0;
const node_1 = require("@sentry/node");
const stun_1 = __importDefault(require("stun"));
const profiling_node_1 = require("@sentry/profiling-node");
const ping_1 = require("../../utils/ping");
const http_1 = require("../../utils/http");
const os_1 = require("os");
const ip_1 = __importDefault(require("../../utils/ip"));
const context_1 = require("../../context");
async function initSentry({ dsn, monikaVersion, }) {
    (0, node_1.init)({
        dsn,
        integrations: [(0, profiling_node_1.nodeProfilingIntegration)()],
        tracesSampleRate: 1,
    });
    // Get current public IP
    let publicIp;
    const connection = await (0, ping_1.sendPing)('stun.l.google.com');
    if (connection.alive) {
        const response = await stun_1.default.request('stun.l.google.com:19302');
        publicIp = response?.getXorAddress()?.address;
    }
    const response = await (0, http_1.sendHttpRequest)({
        url: `http://ip-api.com/json/${publicIp}`,
    });
    const { country, city, isp } = response.data;
    const tags = {
        country,
        city,
        hostname: (0, os_1.hostname)(),
        isp,
        privateIp: (0, ip_1.default)(),
        publicIp,
        monikaVersion,
    };
    if ((0, context_1.getContext)().flags.symonMonikaId) {
        tags.symonMonikaId = (0, context_1.getContext)().flags.symonMonikaId;
    }
    (0, node_1.setTags)(tags);
}
exports.initSentry = initSentry;
//# sourceMappingURL=index.js.map