"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AtlassianStatusPageAPI = exports.validateConfig = exports.validator = exports.slug = void 0;
const axios_1 = __importStar(require("axios"));
const http_1 = __importDefault(require("http"));
const https_1 = __importDefault(require("https"));
const joi_1 = __importDefault(require("joi"));
const database_1 = require("./database");
exports.slug = 'statuspage';
exports.validator = joi_1.default.object({
    pageID: joi_1.default.string().required().label('Page ID'),
    apiKey: joi_1.default.string().required().label('API Key'),
}).required();
function validateConfig(statusPageConfig) {
    const { error } = exports.validator.validate(statusPageConfig);
    return error ? `Statuspage notification: ${error?.message}` : '';
}
exports.validateConfig = validateConfig;
class AtlassianStatusPageAPI {
    constructor(apiKey, pageID) {
        this.statusPageBaseURL = 'https://api.statuspage.io';
        this.pageID = '';
        this.axiosConfig = {};
        this.pageID = pageID;
        this.axiosConfig = {
            // 10 sec timeout
            timeout: 10000,
            // keepAlive pools and reuses TCP connections, so it's faster
            httpAgent: new http_1.default.Agent({ keepAlive: true }),
            httpsAgent: new https_1.default.Agent({ keepAlive: true }),
            // follow up to 10 HTTP 3xx redirects
            maxRedirects: 10,
            headers: {
                Authorization: `OAuth ${apiKey}`,
                'Content-Type': 'application/json',
            },
        };
    }
    async notify({ probeID, url, type }) {
        switch (type) {
            case 'incident': {
                const incidentID = await this.createIncident({ probeID, url });
                return incidentID;
            }
            case 'recovery': {
                const incidentID = await this.updateIncident({ probeID, url });
                return incidentID;
            }
            default: {
                throw new Error(`Statuspage notification: type ${type} is unknown`);
            }
        }
    }
    async createIncident({ probeID, url }) {
        const incident = await (0, database_1.findIncident)({
            probeID,
            status: 'investigating',
            url,
        });
        // prevent duplicate incident
        if (incident) {
            return incident.incident_id;
        }
        const status = 'investigating';
        const data = {
            incident: {
                name: 'Service is down',
                status,
            },
        };
        try {
            const resp = await axios_1.default.post(`${this.statusPageBaseURL}/v1/pages/${this.pageID}/incidents`, data, this.axiosConfig);
            const incidentID = resp?.data?.id;
            await (0, database_1.insertIncident)({ incidentID, probeID, status, url });
            return incidentID;
        }
        catch (error) {
            const axiosError = error instanceof axios_1.AxiosError ? error : new axios_1.AxiosError();
            throw new Error(`${axiosError?.message}${axiosError?.response?.data
                ? `. ${axiosError?.response?.data?.message}`
                : ''}`);
        }
    }
    async updateIncident({ probeID, url }) {
        const status = 'resolved';
        const data = {
            incident: {
                name: 'Service is up',
                status,
            },
        };
        const incident = await (0, database_1.findIncident)({
            probeID,
            status: 'investigating',
            url,
        });
        if (!incident) {
            throw new Error('Statuspage notification: Incident is not found.');
        }
        const { incident_id: incidentID } = incident;
        try {
            await axios_1.default.patch(`${this.statusPageBaseURL}/v1/pages/${this.pageID}/incidents/${incidentID}`, data, this.axiosConfig);
        }
        catch (error) {
            const axiosError = error instanceof axios_1.AxiosError ? error : new axios_1.AxiosError();
            throw new Error(`${axiosError?.message}${axiosError?.response?.data
                ? `. ${axiosError?.response?.data?.message}`
                : ''}`);
        }
        await (0, database_1.updateIncident)({ incidentID, status });
        return incidentID;
    }
}
exports.AtlassianStatusPageAPI = AtlassianStatusPageAPI;
//# sourceMappingURL=index.js.map