"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const msw_1 = require("msw");
const node_1 = require("msw/node");
const _1 = __importDefault(require("."));
const context_1 = require("../context");
const probe_1 = require("../components/config/probe");
const validation_1 = require("../components/config/validation");
const incident_1 = require("../components/incident");
const events_1 = __importDefault(require("../events"));
const flag_1 = require("../flag");
const events_2 = require("../utils/events");
const catch_error_handler_1 = require("../utils/catch-error-handler");
const probe_state_1 = require("../utils/probe-state");
const config = {
    version: 'f7c35f9f873da44bca433427b4d30fc5',
    probes: [
        {
            id: '1',
            name: 'test',
            interval: 10,
            requests: [],
            alerts: [],
        },
        {
            id: '2',
            name: 'Example',
            interval: 10,
            requests: [
                {
                    url: 'https://example.com',
                    body: '',
                    followRedirects: 21,
                    timeout: 2000,
                },
            ],
            alerts: [],
        },
    ],
};
const server = (0, node_1.setupServer)(msw_1.http.get('http://ip-api.com/json/192.168.1.1', () => msw_1.HttpResponse.json({
    city: 'jakarta',
    isp: 'hyperjump',
    country: 'Indonesia',
})), msw_1.http.post('http://localhost:4000/api/v1/monika/client-handshake', () => msw_1.HttpResponse.json({
    statusCode: 'ok',
    message: 'Successfully handshaked with Symon',
    data: {
        monikaId: '1234',
    },
})), msw_1.http.get('http://localhost:4000/api/v1/monika/1234/probes', () => msw_1.HttpResponse.json({
    statusCode: 'ok',
    message: 'Successfully get probes configuration',
    data: config.probes,
}, { headers: { etag: config.version || '' } })), msw_1.http.get('https://example.com', () => msw_1.HttpResponse.json({})), msw_1.http.get('http://localhost:4000/api/v1/monika/report', () => msw_1.HttpResponse.json({
    statusCode: 'ok',
    message: 'Successfully report to Symon',
})));
describe('Symon initiate', () => {
    before(() => {
        server.listen();
    });
    beforeEach(() => {
        (0, context_1.resetContext)();
        (0, context_1.setContext)({
            flags: (0, flag_1.sanitizeFlags)({
                symonUrl: 'http://localhost:4000',
                symonKey: 'random-key',
            }),
        });
        // reset probe cache
        for (const { id } of (0, probe_1.getProbes)()) {
            (0, probe_1.deleteProbe)(id);
        }
    });
    afterEach(() => {
        server.resetHandlers();
    });
    after(() => {
        server.close();
        (0, context_1.resetContext)();
    });
    it('should send handshake data on initiate', async () => {
        (0, context_1.setContext)({
            userAgent: 'v1.5.0',
            flags: (0, flag_1.sanitizeFlags)({
                symonUrl: 'http://localhost:4000',
                symonKey: 'random-key',
            }),
        });
        let body = {};
        // mock the outgoing requests
        server.use(msw_1.http.post('http://localhost:4000/api/v1/monika/client-handshake', async ({ request }) => {
            body = await request.json();
            return msw_1.HttpResponse.json({
                statusCode: 'ok',
                message: 'Successfully handshaked with Symon',
                data: {
                    monikaId: '1234',
                },
            });
        }));
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        await symon.initiate();
        await symon.stop();
        (0, test_1.expect)(body.publicIp).equals('192.168.1.1');
        (0, test_1.expect)(body.pid).greaterThan(0);
        (0, test_1.expect)(body.macAddress).length.greaterThan(0);
        (0, test_1.expect)(body.isp).equals('hyperjump');
        (0, test_1.expect)(body.city).equals('jakarta');
        (0, test_1.expect)(body.country).equals('Indonesia');
        (0, test_1.expect)(body.hostname).length.greaterThan(0);
        (0, test_1.expect)(body.privateIp).length.greaterThan(0);
        (0, test_1.expect)(body.os).length.greaterThan(0);
        (0, test_1.expect)(body.version).equals('v1.5.0');
    }).timeout(15000);
    it('should fetch probes config on initiate', async () => {
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        (0, test_1.expect)((0, context_1.getContext)().config).to.be.undefined;
        await symon.initiate();
        await symon.stop();
        (0, test_1.expect)((0, context_1.getContext)().config?.version).deep.eq(config.version);
        (0, test_1.expect)((0, probe_1.getProbes)()).deep.eq(await (0, validation_1.validateProbes)(config.probes));
    }).timeout(15000);
    it('should throw an error if the request to get probes is failed', async () => {
        // arrange
        server.use(msw_1.http.post('http://localhost:4000/api/v1/monika/client-handshake', () => msw_1.HttpResponse.json({
            statusCode: 'ok',
            message: 'Successfully handshaked with Symon',
            data: {
                monikaId: '1234',
            },
        })), msw_1.http.get('http://localhost:4000/api/v1/monika/1234/probes', () => {
            throw new Error('Failed to get probes from Symon');
        }));
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        let errorMessage = '';
        try {
            // act
            await symon.initiate();
        }
        catch (error) {
            errorMessage = (0, catch_error_handler_1.getErrorMessage)(error);
        }
        await symon.stop();
        // assert
        (0, test_1.expect)(errorMessage).eq('Failed to get probes from Symon');
    }).timeout(15000);
    it('should send event to Symon when incident or recovery happens', async () => {
        // arrange
        let body = {};
        server.use(msw_1.http.post('http://localhost:4000/api/v1/monika/events', async ({ request }) => {
            body = await request.json();
            return msw_1.HttpResponse.json({
                message: 'Successfully send incident event to Symon',
                data: null,
            });
        }));
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
            symonMonikaId: '1234',
        }));
        await symon.initiate();
        // act
        (0, events_2.getEventEmitter)().emit(events_1.default.probe.notification.willSend, {
            probeState: 'DOWN',
            validation: {
                response: {
                    headers: '',
                    status: 400,
                    responseTime: 1000,
                },
            },
            alertId: 'p422i',
        });
        await symon.stop();
        // assert
        (0, test_1.expect)(body.monikaId).equals('1234');
        (0, test_1.expect)(body.event).equals('incident');
        (0, test_1.expect)(body.alertId).equals('p422i');
        (0, test_1.expect)(body.response).deep.equals({
            headers: {},
            status: 400,
            time: 1000,
        });
    }).timeout(15000);
    it('should add a new probe', async () => {
        // arrange
        const newProbe = {
            id: '3',
            name: 'New Probe',
            interval: 2,
            requests: [
                {
                    url: 'https://example.com',
                    body: '',
                    followRedirects: 21,
                    timeout: 2000,
                },
            ],
            alerts: [],
        };
        server.use(msw_1.http.get('http://localhost:4000/api/v1/monika/1234/probe-changes', () => msw_1.HttpResponse.json({
            message: 'Successfully get probe changes',
            data: [{ type: 'add', probe: newProbe }],
        })));
        const symonGetProbesIntervalMs = 100;
        (0, context_1.setContext)({
            flags: (0, flag_1.sanitizeFlags)({
                symonUrl: 'http://localhost:4000',
                symonKey: 'random-key',
                symonGetProbesIntervalMs,
            }),
        });
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        // 1. Check initial probe cache
        (0, test_1.expect)((0, probe_1.getProbes)()).deep.eq([]);
        // act
        // 2. Initiate Symon and get all the probes
        await symon.initiate();
        // assert
        // 3. Check the probe data after connected to Symon
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(2);
        // act
        // 4. Wait for the probe fetch to run
        await sleep(symonGetProbesIntervalMs);
        // assert
        // 5. Check the updated probe cache
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(3);
        await symon.stop();
    }).timeout(15000);
    it('should update a probe', async () => {
        // arrange
        server.use(msw_1.http.get('http://localhost:4000/api/v1/monika/1234/probe-changes', () => msw_1.HttpResponse.json({
            message: 'Successfully get probe changes',
            data: [
                {
                    type: 'update',
                    // eslint-disable-next-line camelcase
                    probe_id: '1',
                    probe: { ...(0, probe_1.findProbe)('1'), interval: 2 },
                },
            ],
        })));
        const symonGetProbesIntervalMs = 100;
        (0, context_1.setContext)({
            flags: (0, flag_1.sanitizeFlags)({
                symonUrl: 'http://localhost:4000',
                symonKey: 'random-key',
                symonGetProbesIntervalMs,
            }),
        });
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        // 1. Check initial probe cache
        (0, test_1.expect)((0, probe_1.getProbes)()).deep.eq([]);
        // act
        // 2. Initiate Symon and get all the probes
        await symon.initiate();
        // assert
        // 3. Check the probe data after connected to Symon
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(2);
        // act
        // 4. Wait for the probe fetch to run
        await sleep(symonGetProbesIntervalMs);
        // assert
        // 5. Check the updated probe cache
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(2);
        (0, test_1.expect)((0, probe_1.findProbe)('1')?.interval).eq(2);
        await symon.stop();
    }).timeout(15000);
    it('should delete a probe', async () => {
        // arrange
        server.use(msw_1.http.get('http://localhost:4000/api/v1/monika/1234/probe-changes', () => msw_1.HttpResponse.json({
            message: 'Successfully get probe changes',
            data: [
                {
                    type: 'delete',
                    // eslint-disable-next-line camelcase
                    probe_id: '1',
                    probe: {},
                },
            ],
        })));
        const symonGetProbesIntervalMs = 100;
        (0, context_1.setContext)({
            flags: (0, flag_1.sanitizeFlags)({
                symonUrl: 'http://localhost:4000',
                symonKey: 'random-key',
                symonGetProbesIntervalMs,
            }),
        });
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        // 1. Check initial probe cache
        (0, test_1.expect)((0, probe_1.getProbes)()).deep.eq([]);
        // act
        // 2. Initiate Symon and get all the probes
        await symon.initiate();
        // assert
        // 3. Check the probe data after connected to Symon
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(2);
        // act
        // 4. Wait for the probe fetch to run
        await sleep(symonGetProbesIntervalMs);
        // assert
        // 5. Check the updated probe cache
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(1);
        await symon.stop();
    }).timeout(15000);
    it('should disable a probe', async () => {
        // arrange
        server.use(msw_1.http.get('http://localhost:4000/api/v1/monika/1234/probe-changes', () => msw_1.HttpResponse.json({
            message: 'Successfully get probe changes',
            data: [
                {
                    type: 'disabled',
                    // eslint-disable-next-line camelcase
                    probe_id: '1',
                    probe: {},
                },
            ],
        })));
        const symonGetProbesIntervalMs = 100;
        (0, context_1.setContext)({
            flags: (0, flag_1.sanitizeFlags)({
                symonUrl: 'http://localhost:4000',
                symonKey: 'random-key',
                symonGetProbesIntervalMs,
            }),
        });
        const symon = new _1.default((0, flag_1.sanitizeFlags)({
            symonUrl: 'http://localhost:4000',
            symonKey: 'abcd',
        }));
        // 1. Check initial probe cache
        (0, test_1.expect)((0, probe_1.getProbes)()).deep.eq([]);
        // act
        // 2. Initiate Symon and get all the probes
        await symon.initiate();
        // assert
        // 3. Check the probe data after connected to Symon
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(2);
        (0, probe_state_1.initializeProbeStates)((0, probe_1.getProbes)());
        (0, incident_1.addIncident)({
            alert: { assertion: '', id: '', message: '' },
            probeID: config.probes[0].id,
            probeRequestURL: '',
        });
        (0, incident_1.addIncident)({
            alert: { assertion: '', id: '', message: '' },
            probeID: config.probes[1].id,
            probeRequestURL: '',
        });
        // act
        // 4. Wait for the probe fetch to run
        await sleep(symonGetProbesIntervalMs);
        // assert
        // 5. Check the updated probe cache and state
        (0, test_1.expect)((0, probe_1.getProbes)().length).eq(1);
        (0, test_1.expect)((0, probe_state_1.getProbeState)('1')).to.be.undefined;
        (0, test_1.expect)((0, probe_state_1.getProbeState)('2')).to.not.undefined;
        (0, test_1.expect)((0, incident_1.findIncident)('1')).to.be.undefined;
        (0, test_1.expect)((0, incident_1.findIncident)('2')).to.not.be.undefined;
        await symon.stop();
    }).timeout(15000);
});
function sleep(durationMs) {
    return new Promise((resolve) => {
        setTimeout(resolve, durationMs);
    });
}
//# sourceMappingURL=index.test.js.map