"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const path_1 = __importDefault(require("path"));
const sqlite_1 = require("sqlite");
const sqlite3_1 = require("sqlite3");
const history_1 = require("../components/logger/history");
const pino_1 = require("../utils/pino");
const dbPath = path_1.default.resolve(process.cwd(), 'monika-logs.db');
exports.default = async (stringifiedData) => {
    try {
        const parsedData = JSON.parse(stringifiedData);
        const { apiKey, monikaId, probeIds, reportProbesLimit, url } = parsedData;
        // Open database
        const sqlite3 = (0, sqlite3_1.verbose)();
        const db = await (0, sqlite_1.open)({
            driver: sqlite3.Database,
            filename: dbPath,
            mode: sqlite3.OPEN_READWRITE || sqlite3.OPEN_CREATE,
        });
        // Updating requests and notifications to report
        const logs = await (0, history_1.getUnreportedLogs)(probeIds, reportProbesLimit, db);
        const { requests } = logs;
        const { notifications } = logs;
        if (requests.length === 0 && notifications.length === 0) {
            // No requests or notifications to report
            pino_1.log.info('Nothing to report');
        }
        else {
            // Hit the Symon API for receiving Monika report
            // With the compressed requests and notifications data
            await (0, axios_1.default)({
                data: {
                    data: {
                        notifications,
                        requests,
                    },
                    monikaId,
                },
                headers: {
                    'Content-Type': 'application/json',
                    'x-api-key': apiKey,
                },
                method: 'POST',
                url: `${url}/api/v1/monika/report`,
            });
            pino_1.log.info(`Reported ${requests.length} requests and ${notifications.length} notifications.`);
            // Delete the reported requests
            await (0, history_1.deleteRequestLogs)(requests.map((l) => l.probeId), db);
            pino_1.log.info(`Deleted ${requests.length} reported request`);
            // Delete the reported notifications
            await (0, history_1.deleteNotificationLogs)(notifications.map((l) => l.probeId), db);
            pino_1.log.info(`Deleted ${notifications.length} reported request`);
        }
    }
    catch (error) {
        pino_1.log.error("Warning: Can't report history to Symon. " + error.message);
    }
};
//# sourceMappingURL=report-to-symon.js.map