/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
import type { ArraySchema, ObjectSchema } from 'joi';
type BaseNotificationMessageMeta = {
    type: string;
    time: string;
    hostname: string;
    privateIpAddress: string;
    publicIpAddress: string;
    [key: string]: unknown;
    monikaInstance?: string;
    version: string;
};
interface NotificationIncidentRecoveryMessageMeta extends BaseNotificationMessageMeta {
    probeID: string;
    type: 'incident' | 'recovery';
    url: string;
}
interface NotificationStartTerminationMessageMeta extends BaseNotificationMessageMeta {
    type: 'start' | 'termination';
}
interface NotificationStatusUpdateMessageMeta extends BaseNotificationMessageMeta {
    type: 'status-update';
    numberOfProbes: number;
    averageResponseTime: number;
    numberOfIncidents: number;
    numberOfRecoveries: number;
    numberOfSentNotifications: number;
}
export type NotificationMessage = {
    subject: string;
    body: string;
    summary: string;
    meta: NotificationIncidentRecoveryMessageMeta | NotificationStartTerminationMessageMeta | NotificationStatusUpdateMessageMeta;
};
type NotificationChannel<T = object, U = object> = {
    validator: ArraySchema | ObjectSchema;
    send: (notificationData: T | T[] | undefined, message: NotificationMessage) => Promise<void>;
    sendWithCustomContent?: (notificationData: T | T[], customContent: U | U[]) => Promise<void>;
    additionalStartupMessage?: (notificationData: T) => string;
};
export type Notification = {
    id: string;
    type: string;
    data?: object;
};
export declare const channels: Record<string, NotificationChannel>;
export {};
