"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.additionalStartupMessage = exports.sendWithCustomContent = exports.send = exports.validator = void 0;
const tslib_1 = require("tslib");
const form_data_1 = tslib_1.__importDefault(require("form-data"));
const joi_1 = tslib_1.__importDefault(require("joi"));
const mailgen_1 = tslib_1.__importDefault(require("mailgen"));
const default_sender_1 = require("../utils/default-sender");
const http_1 = require("../utils/http");
exports.validator = joi_1.default.object().keys({
    recipients: joi_1.default.array()
        .required()
        .items(joi_1.default.string().required().email().label('Mailgun Email Recipients'))
        .label('Mailgun Recipients'),
    apiKey: joi_1.default.string().required().label('Mailgun API Key'),
    domain: joi_1.default.string().required().label('Mailgun Domain'),
});
const isContent = (data) => {
    const keys = ['from', 'subject', 'html', 'text'];
    return keys.every((k) => Object.prototype.hasOwnProperty.call(data, k));
};
const _send = async ({ apiKey, domain, recipients }, data) => {
    var _a, _b;
    const url = `https://api.mailgun.net/v3/${domain}/messages`;
    const auth = Buffer.from('api:' + apiKey).toString('base64');
    const theData = isContent(data)
        ? data
        : getContent({ body: data.body, subject: data.subject, domain });
    const formData = new form_data_1.default();
    formData.append('from', theData.from);
    formData.append('subject', theData.subject);
    formData.append('html', theData.html);
    formData.append('text', theData.text);
    for (const email of recipients)
        formData.append('to', email);
    if ((_a = theData.headers) === null || _a === void 0 ? void 0 : _a.References)
        formData.append('h:References', (_b = theData.headers) === null || _b === void 0 ? void 0 : _b.References);
    await (0, http_1.sendHttpRequest)({
        method: 'POST',
        url,
        headers: {
            Authorization: 'Basic ' + auth,
        },
        data: formData,
    });
};
const send = async (notificationData, notificationMessage) => {
    await _send(notificationData, notificationMessage);
};
exports.send = send;
const sendWithCustomContent = async (notificationData, content) => {
    await _send(notificationData, content);
};
exports.sendWithCustomContent = sendWithCustomContent;
function getContent({ body, subject, domain, }) {
    const DEFAULT_SENDER_NAME = (0, default_sender_1.getSender)().name;
    const from = `${DEFAULT_SENDER_NAME} <mailgun@${domain}>`;
    const mailGenerator = new mailgen_1.default({
        theme: 'default',
        product: {
            name: 'Monika',
            link: 'https://monika.hyperjump.tech/',
            logo: 'https://raw.githubusercontent.com/hyperjumptech/monika/main/docs/public/monika.svg',
        },
    });
    const email = {
        body: {
            intro: [subject, ...body.split(/\r?\n/)],
        },
    };
    const html = mailGenerator.generate(email);
    const text = mailGenerator.generatePlaintext(email);
    return {
        from,
        subject,
        html,
        text,
    };
}
function additionalStartupMessage({ domain, recipients, }) {
    return `    Recipients: ${recipients.join(', ')}\n    Domain: ${domain}\n`;
}
exports.additionalStartupMessage = additionalStartupMessage;
