"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendWithCustomContent = exports.send = exports.validator = void 0;
const tslib_1 = require("tslib");
const joi_1 = tslib_1.__importDefault(require("joi"));
const http_1 = require("../utils/http");
exports.validator = joi_1.default.object().keys({
    url: joi_1.default.string().uri().required().label('Monika Notification URL'),
});
const send = async ({ url }, message) => {
    const content = getContent(message);
    if (!content) {
        throw new Error('Unknown notification type');
    }
    await (0, http_1.sendHttpRequest)({
        method: 'POST',
        url,
        data: content,
    });
};
exports.send = send;
const sendWithCustomContent = async ({ url }, content) => {
    if (!content) {
        throw new Error('Unknown notification type');
    }
    await (0, http_1.sendHttpRequest)({
        method: 'POST',
        url,
        data: content,
    });
};
exports.sendWithCustomContent = sendWithCustomContent;
function getContent({ body, meta, summary, }) {
    const { averageResponseTime, maxResponseTime, minResponseTime, numberOfIncidents, numberOfProbes, numberOfRecoveries, numberOfSentNotifications, time, type, url, monikaInstance, } = meta;
    switch (type) {
        case 'start':
        case 'termination': {
            return {
                type,
                // eslint-disable-next-line camelcase
                ip_address: body,
            };
        }
        case 'incident':
        case 'recovery': {
            return {
                type,
                alert: summary,
                url,
                time,
                monika: monikaInstance,
            };
        }
        case 'status-update': {
            return {
                type,
                time,
                monika: monikaInstance,
                numberOfProbes: String(numberOfProbes),
                maxResponseTime: String(maxResponseTime),
                minResponseTime: String(minResponseTime),
                averageResponseTime: String(averageResponseTime),
                numberOfIncidents: String(numberOfIncidents),
                numberOfRecoveries: String(numberOfRecoveries),
                numberOfSentNotifications: String(numberOfSentNotifications),
            };
        }
        default: {
            break;
        }
    }
}
