"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.send = exports.validator = void 0;
const tslib_1 = require("tslib");
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2022 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
const joi_1 = tslib_1.__importDefault(require("joi"));
const http_1 = require("../utils/http");
exports.validator = joi_1.default.array()
    .items(joi_1.default.object({
    key: joi_1.default.string().required().label('Key'),
    probeID: joi_1.default.alternatives()
        .try(joi_1.default.number(), joi_1.default.string())
        .required()
        .label('Probe ID'),
}).required())
    .required();
async function send(configurations, message) {
    var _a;
    const { meta } = message;
    const { type } = meta;
    if (type === 'incident' || type === 'recovery') {
        const url = 'https://events.pagerduty.com/v2/enqueue';
        const { probeID } = meta;
        const routingKey = (_a = configurations.find((config) => config.probeID === probeID)) === null || _a === void 0 ? void 0 : _a.key;
        if (!routingKey) {
            return;
        }
        const eventPayload = transformMessageToEventPayload(routingKey, message);
        if (!eventPayload) {
            throw new Error(`PagerDuty notification: failed to create event payload for probe ${probeID}`);
        }
        const options = {
            url,
            method: 'POST',
            headers: { 'Content-Type': 'application/json' },
            data: JSON.stringify(eventPayload),
        };
        await (0, http_1.sendHttpRequest)(options);
    }
}
exports.send = send;
function transformMessageToEventPayload(routingKey, message) {
    // https://developer.pagerduty.com/docs/ZG9jOjExMDI5NTgw-events-api-v2-overview#pagerduty-common-event-format-pd-cef
    const { meta, summary } = message;
    const { probeID, url, alertQuery, type, publicIpAddress } = meta;
    const dedupKey = `${probeID}:${url}:${alertQuery}`.replace(' ', '');
    /* eslint-disable camelcase */
    if (type === 'incident') {
        return {
            routing_key: routingKey,
            dedup_key: dedupKey,
            event_action: 'trigger',
            payload: {
                summary,
                source: publicIpAddress,
                severity: 'error',
                group: probeID,
            },
        };
    }
    if (type === 'recovery') {
        return {
            routing_key: routingKey,
            dedup_key: dedupKey,
            event_action: 'resolve',
        };
    }
    return null;
}
