"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.additionalStartupMessage = exports.sendWithCustomContent = exports.send = exports.validator = void 0;
const tslib_1 = require("tslib");
const mail_1 = tslib_1.__importDefault(require("@sendgrid/mail"));
const joi_1 = tslib_1.__importDefault(require("joi"));
const mailgen_1 = tslib_1.__importDefault(require("mailgen"));
exports.validator = joi_1.default.object().keys({
    apiKey: joi_1.default.string().required().label('SendGrid API Key'),
    sender: joi_1.default.string().required().label('SendGrid sender email'),
    recipients: joi_1.default.array()
        .required()
        .items(joi_1.default.string().required().email().label('SendGrid email recipients'))
        .label('SendGrid recipients'),
});
const send = async ({ apiKey, recipients, sender }, { body, subject }) => {
    const msg = getContent({ body, subject, sender, recipients });
    mail_1.default.setApiKey(apiKey);
    await mail_1.default.send(msg);
};
exports.send = send;
const sendWithCustomContent = async ({ apiKey }, content) => {
    mail_1.default.setApiKey(apiKey);
    await mail_1.default.send(content);
};
exports.sendWithCustomContent = sendWithCustomContent;
function getContent({ body, subject, sender, recipients, }) {
    const to = recipients === null || recipients === void 0 ? void 0 : recipients.join(',');
    const mailGenerator = new mailgen_1.default({
        theme: 'default',
        product: {
            name: 'Monika',
            link: 'https://monika.hyperjump.tech/',
            logo: 'https://raw.githubusercontent.com/hyperjumptech/monika/main/docs/public/monika.svg',
        },
    });
    const email = {
        body: {
            intro: [subject, ...body.split(/\r?\n/)],
        },
    };
    const html = mailGenerator.generate(email);
    const text = mailGenerator.generatePlaintext(email);
    return {
        to,
        from: sender,
        subject,
        html,
        text,
    };
}
function additionalStartupMessage({ recipients, }) {
    return `    Recipients: ${recipients.join(', ')}\n`;
}
exports.additionalStartupMessage = additionalStartupMessage;
