"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.additionalStartupMessage = exports.send = exports.validator = void 0;
const tslib_1 = require("tslib");
const nodemailer = tslib_1.__importStar(require("nodemailer"));
const mailgen_1 = tslib_1.__importDefault(require("mailgen"));
const joi_1 = tslib_1.__importDefault(require("joi"));
const default_sender_1 = require("../utils/default-sender");
exports.validator = joi_1.default.object().keys({
    hostname: joi_1.default.string().required().label('SMTP Hostname'),
    port: joi_1.default.number().port().required().label('SMTP Port'),
    username: joi_1.default.string().label('SMTP Username'),
    password: joi_1.default.string().label('SMTP Password'),
    recipients: joi_1.default.array()
        .required()
        .items(joi_1.default.string().required().email().label('Email Email Recipients'))
        .label('Email Recipients'),
});
const send = async ({ hostname, password, port, recipients, username }, { body, subject }) => {
    const DEFAULT_EMAIL = (0, default_sender_1.getSender)().email;
    const DEFAULT_SENDER_NAME = 'Monika';
    const transporter = nodemailer.createTransport({
        host: hostname,
        port,
        secure: port === 465,
        auth: {
            user: username,
            pass: password,
        },
    });
    const mailGenerator = new mailgen_1.default({
        theme: 'default',
        product: {
            name: 'Monika',
            link: 'https://monika.hyperjump.tech/',
            logo: 'https://raw.githubusercontent.com/hyperjumptech/monika/main/docs/public/monika.svg',
        },
    });
    const email = {
        body: {
            intro: [subject, ...body.split(/\r?\n/)],
        },
    };
    const html = mailGenerator.generate(email);
    const text = mailGenerator.generatePlaintext(email);
    await transporter.sendMail({
        from: `"${DEFAULT_SENDER_NAME}" <${DEFAULT_EMAIL}>`,
        to: recipients === null || recipients === void 0 ? void 0 : recipients.join(','),
        subject,
        text,
        html,
    });
};
exports.send = send;
function additionalStartupMessage({ hostname, port, recipients, username, }) {
    return `    Recipients: ${recipients.join(', ')}\n    Hostname: ${hostname}\n    Port: ${port}\n    Username: ${username}\n`;
}
exports.additionalStartupMessage = additionalStartupMessage;
