"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.send = exports.validator = void 0;
const tslib_1 = require("tslib");
const joi_1 = tslib_1.__importDefault(require("joi"));
const authorization_1 = require("../utils/authorization");
const http_1 = require("../utils/http");
exports.validator = joi_1.default.object().keys({
    recipients: joi_1.default.array()
        .items(joi_1.default.string().label('WhatsApp Recipients'))
        .label('WhatsApp Recipients'),
    url: joi_1.default.string().uri().required().label('WhatsApp URL'),
    username: joi_1.default.string().required().label('WhatsApp Username'),
    password: joi_1.default.string().required().label('WhatsApp Password'),
});
const send = async (data, { body }) => {
    const token = await loginUser(data);
    await Promise.all(data.recipients.map(async (recipient) => {
        await sendTextMessage({
            recipient,
            token,
            baseUrl: data.url,
            message: body,
        });
    }));
};
exports.send = send;
async function sendTextMessage({ recipient, message, token, baseUrl, }) {
    try {
        const auth = (0, authorization_1.authorize)({ type: 'bearer', token });
        const url = `${baseUrl}/v1/messages`;
        await (0, http_1.sendHttpRequest)({
            method: 'POST',
            url,
            headers: {
                'Content-Type': 'application/json',
                Authorization: auth || '',
            },
            data: {
                to: recipient,
                type: 'text',
                // eslint-disable-next-line camelcase
                recipient_type: 'individual',
                text: {
                    body: message,
                },
            },
        });
    }
    catch (error) {
        throw new Error(`Something wrong with your recipient number, Please check your country code: ${recipient} ${error}`);
    }
}
async function loginUser({ password, url: baseURL, username, }) {
    var _a;
    try {
        const auth = (0, authorization_1.authorize)({ type: 'basic', username, password });
        const url = `${baseURL}/v1/users/login`;
        const resp = await (0, http_1.sendHttpRequest)({
            method: 'POST',
            url,
            headers: {
                'Content-Type': 'application/json',
                Authorization: auth || '',
            },
        });
        const loginResp = resp === null || resp === void 0 ? void 0 : resp.data;
        const hasUser = ((_a = loginResp.users) === null || _a === void 0 ? void 0 : _a.length) > 0;
        if (!hasUser) {
            throw new Error('User not found');
        }
        return loginResp.users[0].token;
    }
    catch (error) {
        throw new Error(`Something wrong with your whatsapp config please check again. error: ${error}`);
    }
}
