"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateNotification = exports.channels = exports.sendNotifications = void 0;
const channel_1 = require("./channel");
const catch_error_handler_1 = require("./utils/catch-error-handler");
const default_sender_1 = require("./utils/default-sender");
async function sendNotifications(notifications, message, sender) {
    if (sender) {
        (0, default_sender_1.updateSender)(sender);
    }
    // Map notifications to an array of results
    const results = await Promise.all(notifications.map(async ({ data, type }) => {
        const channel = channel_1.channels[type];
        try {
            if (!channel) {
                throw new Error('Notification channel is not available');
            }
            await channel.send(data, message);
            return { type, success: true };
        }
        catch (error) {
            const errorMessage = (0, catch_error_handler_1.getErrorMessage)(error);
            console.error(`Failed to send message using ${type}, please check your ${type} notification config.\nMessage: ${errorMessage}`);
            return { type, success: false };
        }
    }));
    return results;
}
exports.sendNotifications = sendNotifications;
var channel_2 = require("./channel");
Object.defineProperty(exports, "channels", { enumerable: true, get: function () { return channel_2.channels; } });
var notification_1 = require("./validator/notification");
Object.defineProperty(exports, "validateNotification", { enumerable: true, get: function () { return notification_1.validateNotification; } });
