"use strict";
/**********************************************************************************
 * MIT License                                                                    *
 *                                                                                *
 * Copyright (c) 2021 Hyperjump Technology                                        *
 *                                                                                *
 * Permission is hereby granted, free of charge, to any person obtaining a copy   *
 * of this software and associated documentation files (the "Software"), to deal  *
 * in the Software without restriction, including without limitation the rights   *
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      *
 * copies of the Software, and to permit persons to whom the Software is          *
 * furnished to do so, subject to the following conditions:                       *
 *                                                                                *
 * The above copyright notice and this permission notice shall be included in all *
 * copies or substantial portions of the Software.                                *
 *                                                                                *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  *
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  *
 * SOFTWARE.                                                                      *
 **********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateNotification = void 0;
const channel_1 = require("../channel");
const catch_error_handler_1 = require("../utils/catch-error-handler");
const validateNotification = async (notifications) => {
    const hasNotification = notifications.length > 0;
    if (!hasNotification) {
        return;
    }
    await Promise.all(notifications.map(async ({ data, type }) => {
        try {
            const channel = channel_1.channels[type];
            if (!(channel === null || channel === void 0 ? void 0 : channel.validator)) {
                throw new Error('Notifications type is not allowed');
            }
            await channel.validator.validateAsync(data);
        }
        catch (error) {
            const message = (0, catch_error_handler_1.getErrorMessage)(error);
            throw new Error(`${message} (${type})`);
        }
    }));
};
exports.validateNotification = validateNotification;
